<?php

  /*****************************************************************
   **                                                             **
   **             ___________________________________             **
   **            |                                   |            **
   **            |   [SimonStenhouse.NET] Download   |            **
   **            |___________________________________|            **
   **                                                             **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  Author:  Simon Stenhouse                                   **
   **  Date:    02.11.2006                                        **
   **  Version: 1.5                                               **
   **  Website: http://www.simonstenhouse.net/                    **
   **  License: http://www.gnu.org/licenses/gpl.txt               **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  Requirements:                                              **
   **                                                             **
   **   - PHP 4 >= 4.3.0 or PHP 5                                 **
   **                                                             **
   **  Features:                                                  **
   **                                                             **
   **   - Easy Installation                                       **
   **   - Limit the speed of downloads                            **
   **   - Supports unlimited file types                           **
   **   - Prevents the leeching of your files                     **
   **   - Flat file system (no database needed)                   **
   **   - Hides the actual location of your files                 **
   **   - Categorise your files for easy management               **
   **   - Show the size of a file in a user friendly way          **
   **   - Show the number of times a file has been downloaded     **
   **   - Logs all downloads as well as leech and hack attempts   **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  Installation:                                              **
   **                                                             **
   **   1 Open download.php and adjust the settings in the        **
   **     configuration area as needed.                           **
   **                                                             **
   **   2 Upload download.php to your sites root directory.       **
   **                                                             **
   **   3 Open leech.php, modify it to suit your site, and        **
   **     then upload it to the root of your site.                **
   **                                                             **
   **   4 Open hack.php, modify it to suit your site, and         **
   **     then upload it to the root of your site.                **
   **                                                             **
   **   5 Create a directory named 'data' off of the root         **
   **     and then CHMOD 777 that directory.                      **
   **                                                             **
   **   6 Create a directory named 'hidden' off of the root.      **
   **     NOTE: I advise you to choose a different name for       **
   **     this directory, which is where your downloadable        **
   **     files will hide, and adjust the relevant setting        **
   **     in the configuration area.                              **
   **                                                             **
   **   7 For categories, create subdirectories in your "hidden"  **
   **     directory. Upload the test.txt files to try it out.     **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  Resulting Structure:                                       **
   **                                                             **
   **   /download.php                                             **
   **   /leech.php                                                **
   **   /hack.php                                                 **
   **   /data/                                                    **
   **   /hidden/                                                  **
   **   /hidden/test.txt                                          **
   **   /hidden/test/ (category)                                  **
   **   /hidden/test/test.txt                                     **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  Usage example:                                             **
   **                                                             **
   **   Download Link                                             **
   **   -------------                                             **
   **                                                             **
   **   There are 3 different ways to have your download links.   **
   **                                                             **
   **    1: This is the original configuration where you just     **
   **       supply the filename as the query string.              **
   **                                                             **
   **   <a href="download.php?test.txt">Download</a>              **
   **                                                             **
   **    2: This is an alternate to the above.                    **
   **       "file" is for the filename.                           **
   **                                                             **
   **   <a href="download.php?file=test.txt">Download</a>         **
   **                                                             **
   **    3: This one requires you to supply two arguments.        **
   **       "file" is for the filename.                           **
   **       "category" is for the category (subdirectory)         **
   **       in which the file is located.                         **
   **                                                             **
   **   <a href="download.php?file=test.txt&category=test">       **
   **    Download</a>                                             **
   **                                                             **
   **                                                             **
   **   File Size                                                 **
   **   ---------                                                 **
   **                                                             **
   **   1: If the file is NOT in a category.                      **
   **                                                             **
   **   <?php echo download_size('test.txt'); ?>                  **
   **                                                             **
   **   2: If the file IS in a category.                          **
   **                                                             **
   **   <?php echo download_size('test.txt', 'category'); ?>      **
   **                                                             **
   **                                                             **
   **   File Count                                                **
   **   ----------                                                **
   **                                                             **
   **   1: If the file is NOT in a category.                      **
   **                                                             **
   **   <?php echo download_count('test.txt'); ?>                 **
   **                                                             **
   **   2: If the file IS in a category.                          **
   **                                                             **
   **   <?php echo download_count('test.txt', 'category'); ?>     **
   **                                                             **
   **                                                             **
   **   See the included 'example.php' file for a more detailed   **
   **   example.                                                  **
   **                                                             **
   **  ---------------------------------------------------------  **
   **                                                             **
   **  History:                                                   **
   **                                                             **
   **   1.5 - 02.11.2006                                          **
   **                                                             **
   **         Added: Speed Limiter                                **
   **                                                             **
   **          You can now limit the download speed (in KB/s).    **
   **                                                             **
   **         Added: Categories                                   **
   **                                                             **
   **          You can now have subdirectories within your        **
   **          "hidden" download directory. Allows for greater    **
   **          organisation when you have many of files.          **
   **                                                             **
   **          See "Usage example" for more information.          **
   **                                                             **
   **         Added: Allow Null Referers                          **
   **                                                             **
   **          You can now choose whether to allow or deny null   **
   **          referers. Null referers are download requests      **
   **          from unknown sources.                              **
   **                                                             **
   **         Improved: download_size()                           **
   **                                                             **
   **          Reworked and optimised. Decimals for size units    **
   **          except bytes and kilobytes.                        **
   **                                                             **
   **         Improved: Download Logging                          **
   **                                                             **
   **          Changed so only completed downloads are logged.    **
   **                                                             **
   **         Fixed: Spaces in filename bug                       **
   **                                                             **
   **          Filenames with spaces now download correctly.      **
   **                                                             **
   **         Fixed: IE bug [0]                                   **
   **                                                             **
   **          Fixed so filenames with multiple dots (.) would    **
   **          download without the [0] included.For example,     **
   **          in IE the file "download1.3.zip" would download    **
   **          as "download1.3[0].zip".                           **
   **                                                             **
   **   1.2 - 25.03.2006                                          **
   **                                                             **
   **         Improved: Hack Attempt Check                        **
   **                                                             **
   **          Added some extra checks for hack attempts.         **
   **                                                             **
   **   1.1 - 24.12.2005                                          **
   **                                                             **
   **         Improved: download_count() and download_size()      **
   **                                                             **
   **          Changed these functions so they return their       **
   **          result instead of echo'ing them. Users can now     **
   **          do things like adding the download count of        **
   **          multiple files to get an overall total.            **
   **                                                             **
   **   1.0 - 26.11.2005                                          **
   **                                                             **
   **         Full Release with all features present.             **
   **                                                             **
   *****************************************************************/




  /*****************************************************************
   **                                                             **
   **                  C O N F I G U R A T I O N                  **
   **                                                             **
   *****************************************************************/


// PATHS
// -----------------------------------------------------------------

// Root path of your site
$root = $_SERVER['DOCUMENT_ROOT'] . '/';

// Path to downloadable files (will not be revealed to users so they will never know your files real address)
$hidden = 'hidden/';

// Path to data files
// NOTE: This directory must have been CHMOD'd to 777
$data = 'data/';

// Path to and name of your leech warning page
$leech = 'leech.php';

// Path to and name of your hack warning page
$hack = 'hack.php';

// Allow null referer's to download files (true/false).  If true, and the referer value is null, the user will still be allowed to download.  If false, it will be regarded as a leech attempt.  Default is false.
$allow_null_referer = false;

// Limits the download speed (in KB's per second).  Default is 24 KB's per second.
$speed = 24;




  /*****************************************************************
   **                                                             **
   **                      F U N C T I O N S                      **
   **                                                             **
   *****************************************************************/


// PURPOSE:	Check whether a file exists.  If it doesn't, the file is created.
// PARAMS:	[string] $file - The full path and name of a file
// RETURN:	[bool] - True if file exists | False if file doesn't exist but gets created
function download_check_file($file)
{
	if (!file_exists($file))
	{
		$handle = fopen($file, "w");
		fclose($handle);
		chmod($file, 0666);

		return false;
	}

	return true;
}


// PURPOSE:	To return the number of times a file was downloaded.
// PARAMS:	[string] $file - The name of a file, [string] $category - The category in which the file is located
// RETURN:	[echo] Number of times the file was downloaded
function download_count($file, $category='')
{
	global $root, $hidden, $file_download;
	$category = (!empty($category)) ? $category . '/' : '';
	$count = 0;

	if (file_exists($root . $hidden . $category . $file))
	{
		if (file_exists($file_download))
		{
			// Read data from download file into an array
			$download = explode("\n", file_get_contents($file_download));

			// Loop through the downloadarray
			foreach ($download as $line)
			{
				// Split and store array values
				list($stored_file, $stored_ip, $stored_time, $stored_day, $stored_month, $stored_year) = explode("|", $line);

				// Check to see if the file is under a category
				if (substr_count($stored_file, '/') != 0)
				{
					$array = explode('/', $stored_file);
					$stored_category = $array[0] .'/';
					$stored_file = $array[1];

					// Count how many times the file was downloaded
					if ($category == $stored_category && $file == $stored_file)
					{
						$count++;
					}
				}
				else
				{
					// Count how many times the file was downloaded
					if ($category == '' && $file == $stored_file)
					{
						$count++;
					}
				}
			}
		}
	}

	return $count;
}


// PURPOSE:	To return the size of a file in a user friendly format.
// PARAMS:	[string] $file - The name of a file, [string] $category - The category in which the file is located
// RETURN:	[echo] - Size of file
function download_size($file, $category='')
{
    global $root, $hidden;
	$category = (!empty($category)) ? $category . '/' : '';
	$file = $root . $hidden . $category . $file;
	$decimals = 2;

	if (file_exists($file))
	{
		$size = filesize($file);

		$units = array("B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB");
		$units_count = count($units);

		for($unit = 0; $unit < $units_count && $size >= 1024; $unit++)
		{
			$size /= 1024;
		}

		// Don't include decimals if size is B or KB
		$decimals = $unit < 2 ? 0 : $decimals;

		return number_format($size, $decimals) . " " . $units[$unit];
	}
	else
	{
		return "0 B";
	}
}




  /*****************************************************************
   **                                                             **
   **           I N I T I A L I S E   V A R I A B L E S           **
   **                                                             **
   *****************************************************************/

// DATA FILES
$file_download = $root . $data . 'download.dat';
$file_leech    = $root . $data . 'leech.dat';
$file_hack     = $root . $data . 'hack.dat';

// VARIABLES
if (!empty($_GET['file']))
{
	$file = str_replace('%20', ' ', $_GET['file']);
	$category = (!empty($_GET['category'])) ? $_GET['category'] . '/' : '';
}
else
{
	$file = str_replace('%20', ' ', $_SERVER['QUERY_STRING']);
}
$file_real     = $root . $hidden . $category . $file;
$ip            = $_SERVER['REMOTE_ADDR'];

$time          = time();
$day           = date("j");
$month         = date("n");
$year          = date("Y");

// Convert download speed to bytes
$speed = round($speed * 1024);

// Determine domain name of your site
$host          = (substr($_SERVER['HTTP_HOST'], 0, 4) == 'www.') ? substr($_SERVER['HTTP_HOST'], 4, strlen($_SERVER['HTTP_HOST'])) : $_SERVER['HTTP_HOST'];

// Determine domain name of referer site
preg_match("/^(http:\/\/)?([^\/]+)/i", $_SERVER['HTTP_REFERER'], $matches);
$referer       = (substr($matches[2], 0, 4) == 'www.') ? substr($matches[2], 4, strlen($matches[2])) : $matches[2];




  /*****************************************************************
   **                                                             **
   **                         S C R I P T                         **
   **                                                             **
   *****************************************************************/


// Check to see if the download script was called
if (basename($_SERVER['PHP_SELF']) == 'download.php')
{
	if ($_SERVER['QUERY_STRING'] != null)
	{
		// Create log files if they don't exist
		download_check_file($file_download);
		download_check_file($file_leech);
		download_check_file($file_hack);

		// HACK ATTEMPT CHECK
		// Make sure the request isn't escaping to another directory
		if (substr($file, 0, 1) == '.' || strpos($file, '..') > 0 || substr($file, 0, 1) == '/' || strpos($file, '/') > 0)
		{
			if ($referer == null)
			{
				$referer = "none";
			}
			$handle_hack = fopen($file_hack, "a");
			flock($handle_hack, LOCK_EX);
			fwrite($handle_hack, "$category$file|$ip|$time|$day|$month|$year|$referer\n");
			fclose($handle_hack);

			// Hack attempt made so redirect to hack warning page (if found)
			if (file_exists($root . $hack))
			{
				header('Location: http://' . $host . '/' . $hack);
			}
			// Otherwise cause a 403 error (Forbidden)
			else
			{
				header('Location: http://' . $host . '/403');
			}

			die();
		}

		// LEECH ATTEMPT CHECK
		// If the domain name of the referer does not match the
		// the domain name of your site, then someone has tried
		// to leech one of your files!
		if ($referer != null && $referer != $host || $referer == null && !$allow_null_referer)
		{
			if ($referer == null)
			{
				$referer = "none";
			}
			$handle_leech = fopen($file_leech, "a");
			flock($handle_leech, LOCK_EX);
			fwrite($handle_leech, "$category$file|$ip|$time|$day|$month|$year|$referer\n");
			fclose($handle_leech);

			// Leech attempt made so redirect to leech warning page (if found)
			if (file_exists($root . $leech))
			{
				header('Location: http://' . $host . '/' . $leech);
			}
			// Otherwise cause a 403 error (Forbidden)
			else
			{
				header('Location: http://' . $host . '/403');
			}

			die();
		}

		// If requested file exists
		if (file_exists($file_real))
		{
			// Get extension of requested file
			$extension = strtolower(substr(strrchr($file, "."), 1));

			// Determine correct MIME type
			switch($extension)
			{
				case "asf":     $type = "video/x-ms-asf";                break;
				case "avi":     $type = "video/x-msvideo";               break;
				case "bin":     $type = "application/octet-stream";      break;
				case "bmp":     $type = "image/bmp";                     break;
				case "cgi":     $type = "magnus-internal/cgi";           break;
				case "css":     $type = "text/css";                      break;
				case "dcr":     $type = "application/x-director";        break;
				case "dxr":     $type = "application/x-director";        break;
				case "dll":     $type = "application/octet-stream";      break;
				case "doc":     $type = "application/msword";            break;
				case "exe":     $type = "application/octet-stream";      break;
				case "gif":     $type = "image/gif";                     break;
				case "gtar":    $type = "application/x-gtar";            break;
				case "gz":      $type = "application/gzip";              break;
				case "htm":     $type = "text/html";                     break;
				case "html":    $type = "text/html";                     break;
				case "iso":     $type = "application/octet-stream";      break;
				case "jar":     $type = "application/java-archive";      break;
				case "java":    $type = "text/x-java-source";            break;
				case "jnlp":    $type = "application/x-java-jnlp-file";  break;
				case "js":      $type = "application/x-javascript";      break;
				case "jpg":     $type = "image/jpg";                     break;
				case "jpe":     $type = "image/jpg";                     break;
				case "jpeg":    $type = "image/jpg";                     break;
				case "lzh":     $type = "application/octet-stream";      break;
				case "mdb":     $type = "application/mdb";               break;
				case "mid":     $type = "audio/x-midi";                  break;
				case "midi":    $type = "audio/x-midi";                  break;
				case "mov":     $type = "video/quicktime";               break;
				case "mp2":     $type = "audio/x-mpeg";                  break;
				case "mp3":     $type = "audio/mpeg";                    break;
				case "mpg":     $type = "video/mpeg";                    break;
				case "mpe":     $type = "video/mpeg";                    break;
				case "mpeg":    $type = "video/mpeg";                    break;
				case "pdf":     $type = "application/pdf";               break;
				case "php":     $type = "application/x-httpd-php";       break;
				case "png":     $type = "image/png";                     break;
				case "ppt":     $type = "application/mspowerpoint";      break;
				case "qt":      $type = "video/quicktime";               break;
				case "qti":     $type = "image/x-quicktime";             break;
				case "rar":     $type = "encoding/x-compress";           break;
				case "ra":      $type = "audio/x-pn-realaudio";          break;
				case "rm":      $type = "audio/x-pn-realaudio";          break;
				case "ram":     $type = "audio/x-pn-realaudio";          break;
				case "rtf":     $type = "application/rtf";               break;
				case "swa":     $type = "application/x-director";        break;
				case "swf":     $type = "application/x-shockwave-flash"; break;
				case "tar":     $type = "application/x-tar";             break;
				case "tgz":     $type = "application/gzip";              break;
				case "tif":     $type = "image/tiff";                    break;
				case "tiff":    $type = "image/tiff";                    break;
				case "torrent": $type = "application/x-bittorrent";      break;
				case "txt":     $type = "text/plain";                    break;
				case "wav":     $type = "audio/wav";                     break;
				case "wma":     $type = "audio/x-ms-wma";                break;
				case "wmv":     $type = "video/x-ms-wmv";                break;
				case "xls":     $type = "application/xls";               break;
				case "xml":     $type = "application/xml";               break;
				case "7z":      $type = "application/x-compress";        break;
				case "zip":     $type = "application/x-zip-compressed";  break;

				default:        $type = "application/force-download";    break;
			}

			// Fix IE bug [0]
			$header_file = (strstr($_SERVER['HTTP_USER_AGENT'], 'MSIE')) ? preg_replace('/\./', '%2e', $file, substr_count($file, '.') - 1) : $file;

			// Prepare headers
			header("Pragma: public");
			header("Expires: 0");
			header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
			header("Cache-Control: public", false);
			header("Content-Description: File Transfer");
			header("Content-Type: " . $type);
			header("Accept-Ranges: bytes");
			header("Content-Disposition: attachment; filename=\"" . $header_file . "\";");
			header("Content-Transfer-Encoding: binary");
			header("Content-Length: " . filesize($file_real));

			// Send file for download
			if ($stream = fopen($file_real, 'rb'))
			{
				while(!feof($stream) && connection_status() == 0)
				{
					print(fread($stream, $speed));
					flush();
					sleep(1);
				}

				fclose($stream);
			}

			// Only log completed downloads
			if (connection_status() == 0 && !connection_aborted())
			{
				// Log the download
				$handle_download = fopen($file_download, "a");
				flock($handle_download, LOCK_EX);
				fwrite($handle_download, "$category$file|$ip|$time|$day|$month|$year\n");

				fclose($handle_download);
			}
		}
		else
		{
			// Requested file does not exist so cause a 404 error (File not found)
			header('Location: http://' . $host . '/404');

			die();
		}
	}
}
?>