<?php
/****************************************************************************************
 * SMI (Services Maintenance Interventions) est une gestion libre de maintenance et de SAV
 *
 * Version 1.0.4
 *
 * Copyright (C) 2006-2016  Sylvain FATOME
 * This program is free software; you can redistribute it and/or modify it under the terms
 * of the GNU General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program
 * (in the directory docs);
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 * Contact : galawa@free.fr
 *
 * Web : http://smi.no-ip.org
 ****************************************************************************************/


// Vérification des tentatives de hack
$pos = strpos($_SERVER['PHP_SELF'], 'inc.php');
if ($pos !== FALSE) {
    header('Location: ../index.php');
}

/**********************/
/* Gestion des heures */
/**********************/

/**
 * Vérifie si la chaîne est une heure correcte (format xx:xx:xx)
 *
 * @param $heure
 * @return bool
 */
function heurecorrecte($heure)
{
    if ($heure == '') {
        return FALSE;
    } else {
        if (preg_match("/(\d{2})([\:])(\d{2})([\:])(\d{2})/", $heure)) {
            list($heure, $minute, $seconde) = explode(':', $heure);
            if (($heure > 23) OR ($minute > 59) OR ($seconde > 59)) {
                return false;
            } else {
                return true;
            }
        } else {
            return FALSE;
        }
    }
}

/**
 * Vérifie si la chaîne est une heure correcte(format xx:xx)
 *
 * @param $heure
 * @return bool
 */
function heurehhmmcorrecte($heure)
{
    if ($heure == '') {
        return FALSE;
    } else {
        if (preg_match("/(\d{2})([\:])(\d{2})/", $heure)) {
            list($heure, $minute) = explode(':', $heure);
            if (($heure > 23) OR ($minute > 59)) {
                return false;
            } else {
                return true;
            }
        } else {
            return FALSE;
        }
    }
}

/**
 * Formate les heures
 *
 * @param $hre
 * @return string
 */
function formateheure($hre)
{
    $heure = '';

    $expr = "/^[0-9]{1,}\:[0-9]{1,2}\:[0-9]{1,2}$/";
    if (preg_match($expr, $hre)) {
        $heure = $hre;
    }

    return $heure;
}

/**
 * Renvoie une heure en nombre de secondes
 *
 * @param $hr
 * @return int
 */
function heure_sec($hr)
{
    $total_sec = 0;

    if ($hr <> '') {
        $tab_heure = explode(':', $hr);

        list($heures,$minutes,$secondes) = $tab_heure;
        /*
        $heures = $tab_heure[0];
        $minutes = $tab_heure[1];
        $secondes = $tab_heure[2];
        */

        $total_sec = ($heures * 3600) + ($minutes * 60) + $secondes;
    }

    return $total_sec;
}


/**
 * Renvoie un nombre de secondes en heure
 * $lngh : longeur du formatage des heures (de 1 à xxx zéros)
 * si $stripz à TRUE, on n'affiche pas les zéros du début de l'heure, avec au moins 2 chiffres restants
 *
 * @param $se
 * @param int $lngh
 * @param bool $stripzh
 * @return string
 */
function sec_heure($se, $lngh = 2, $stripzh = FALSE)
{
    $sec = abs($se);

    $total_se = $sec;

    $heure = $sec / 3600;
    $heure = floor($heure);

    $total_se -= ($heure * 3600);

    $minute = $total_se / 60;
    $minute = floor($minute);

    $seconde = $total_se - ($minute * 60);

    if ($lngh < 1) {
        $lngh = 1;
    }
    $format = "%'02s";
    if ($stripzh == FALSE) {
        $format = "%'0" . $lngh . 's';
    }
    $heure = sprintf($format, $heure);
    $format = "%'02s";
    $minute = sprintf($format, $minute);
    $seconde = sprintf($format, $seconde);

    $strheure = $heure . ':' . $minute . ':' . $seconde;
    if ($se < 0) {
        $strheure = '-' . $strheure;
    }

    return $strheure;
}

/**
 * Convertion d'une heure "classique" en heure hh(carac de 1 à xxxx) :mm
 *
 * @param $hre
 * @return string
 */
function heure_to_hhmm($hre)
{
    $heurehhmm = '';

    if ($hre <> '') {
        $tab_heure = explode(':', $hre);

        list($heures,$minutes) = $tab_heure;
        /*
        $heures = $tab_heure[0];
        $minutes = $tab_heure[1];
        */

        $heurehhmm = $heures . ':' . $minutes;
    }

    return $heurehhmm;
}

/**
 * Différence, en secondes, entre 2 heures ($t2 = la plus grande)
 *
 * @param $t1
 * @param $t2
 * @return int
 */
function diff_time_sec($t1, $t2)
{
    $diff_sec = 0;

    if (($t1 <> '') AND ($t2 <> '')) {
        $s1 = heure_sec($t1);
        $s2 = heure_sec($t2);

        $diff_sec = $s2 - $s1;
    }

    return $diff_sec;
}

/**
 * Donne une heure de fin en fonction d'une heure + durée en minutes
 *
 * @param $heured
 * @param $dureem
 * @param string $format
 * @return string
 */
function heure_fin($heured, $dureem, $format = '')
{
    $heuref = '00:00:00';
    if (heurecorrecte($heured)) {
        switch ($format) {
            case 'hhmm' :
                $heuref = heure_to_hhmm(sec_heure(heure_sec($heured) + ($dureem * 60)));
                break;
            default :
                $heuref = sec_heure(heure_sec($heured) + ($dureem * 60));
                break;
        }
    }

    return $heuref;
}
