<?php
/****************************************************************************************
 * SMI (Services Maintenance Interventions) est une gestion libre de maintenance et de SAV
 *
 * Version 1.0.4
 *
 * Copyright (C) 2006-2016  Sylvain FATOME
 * This program is free software; you can redistribute it and/or modify it under the terms
 * of the GNU General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program
 * (in the directory docs);
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 * Contact : galawa@free.fr
 *
 * Web : http://smi.no-ip.org
 ****************************************************************************************/

// Vérification des tentatives de hack
$pos = strpos($_SERVER['PHP_SELF'], 'inc.php');
if ($pos !== FALSE) {
    header('Location: ../index.php');
}

/**********************/
/* Gestion des textes */
/**********************/

/**
 * Tronque le texte sur 'x' caractères
 *
 * @param $texte
 * @param $longueur
 *
 * @return string
 */
function tronquetxt($texte, $longueur)
{
    $txt = $texte;
    if ((strlen($texte) + 3) > $longueur) {
        $txt = substr($texte, 0, $longueur - 3) . '...';
    }

    return $txt;
}

/**
 * Remplace les retours des textarea par des sauts de lignes
 *
 * @param $texte
 *
 * @return mixed
 */
function formatetxt($texte)
{
    $saut = chr(13) . chr(10);

    return str_replace($saut, "\n", $texte);
}

/**
 * Remplace les retours des textarea par des sauts de lignes html
 *
 * @param $texte
 *
 * @return mixed
 */
function formatetxtbr($texte)
{
    $saut = chr(13) . chr(10);

    return str_replace($saut, '<br />', $texte);
}

/**
 * Césure le texte sur 'x' caractères de largeur
 *
 * @param $texte
 * @param $largeur
 *
 * @return string
 */
function cesuretxt($texte, $largeur)
{
    return wordwrap($texte, $largeur, '<br />');
}

/**
 * Césure un texte en lignes d'un tableau
 *
 * @param $texte
 * @param $largeur
 *
 * @return array
 */
function cesuretxt_tab($texte, $largeur)
{
    $ligne_cesure = [];
    $recup_lignes = explode(chr(13) . chr(10), $texte); // On récupère les lignes du bloc texte

    if ((strlen($texte) <= $largeur) AND (count($recup_lignes) == 1)) {
        $ligne_cesure[0] = $texte;
    } else {
        $carac_speciaux = [':', '!', '?', '.', ';', ',', '/', '%'];

        $index_ligne_cesure = 0;
        $ligne_cesure[0] = '';

        // Traitement des chaque ligne du bloc
        foreach ($recup_lignes as $ligne) {
            unset($recup_mots);
            $recup_mots = explode(' ', $ligne); // On récupère les mots de la ligne

            $j = 0;
            unset($tab_mots);
            $tab_mots = [];

            // Traitement de chaque mot de la ligne traitée
            foreach ($recup_mots as $mot) {
                if (trim($mot) <> '') // On ne traite que les mots, pas les blancs (élimination des espaces multiples)
                {
                    // Le mot fait un caractère de long, il faut faire quelques contrôles
                    if (strlen($mot) == 1) {
                        // On contrôle si c'est un caractère spécial.
                        if (exist_in_array($mot, $carac_speciaux)) {
                            if ($j <> 0) // Oui et ce n'est pas le 1er mot = on "colle" au mot précédent dans le tableau des mots de la ligne traitée
                            {
                                $tab_mots[$j - 1] .= ' ' . $mot;
                            }
                        } else // Non, on ajoute le mot au tableau des mots de la ligne traitée
                        {
                            $tab_mots[$j] = $mot;
                            $j++;
                        }
                    } else // Non, on ajoute le mot au tableau des mots de la ligne traitée
                    {
                        $tab_mots[$j] = $mot;
                        $j++;
                    }
                } else {
                    $tab_mots[$j] = '';
                }
            }

            // Traitement du tableau des mots récupéré sur la ligne en cours de traitement
            foreach ($tab_mots as $mot) {
                $nouv_txt_ligne = trim($ligne_cesure[$index_ligne_cesure] . ' ' . $mot);

                // On vérifie que l'on a pas dépassé la largeur maximale
                // Non, on peut ajouter le mot à la ligne de l'affichage césuré
                if (strlen($nouv_txt_ligne) <= $largeur) {
                    $ligne_cesure[$index_ligne_cesure] = $nouv_txt_ligne;
                } else // Oui, on met un saut de ligne et on ajoute une ligne à l'affichage césuré

                {
                    $index_ligne_cesure++;
                    $ligne_cesure[$index_ligne_cesure] = $mot;
                }
            }
            // On a fini de traiter la ligne, on passe à la ligne suivante
            $index_ligne_cesure++;
        }
    }
    return $ligne_cesure;
}

/**
 * Converti une chaîne en majuscules (avec suppression des accents)
 *
 * @param $texte
 *
 * @return string
 */
function str_majuscules($texte)
{
    $tab_conv = [
        'à' => 'À',
        'á' => 'Á',
        'â' => 'Â',
        'ã' => 'Ã',
        'ä' => 'Ä',
        'å' => 'Å',
        'ç' => 'Ç',
        'è' => 'È',
        'é' => 'É',
        'ê' => 'Ê',
        'ë' => 'Ë',
        'ì' => 'Ì',
        'í' => 'Í',
        'î' => 'Î',
        'ï' => 'Ï',
        'ð' => 'Ð',
        'ò' => 'Ò',
        'ó' => 'Ó',
        'ô' => 'Ô',
        'õ' => 'Õ',
        'ö' => 'Ö',
        'ù' => 'Ù',
        'ú' => 'Ú',
        'û' => 'Û',
        'ü' => 'Ü',
        'ý' => 'Ý',
        'ÿ' => 'Ÿ',
        'ñ' => 'Ñ'
    ];
    $str = strtr($texte, $tab_conv);
    $str = strtoupper($str);

    return $str;
}

/**
 * Vérifie présence d'une chaîne dans une séquence de caractères séparés par des '-'
 *
 * @param $chaine
 * @param $sequence
 *
 * @return bool
 */
function exist_chaine_in_seq($chaine, $sequence)
{
    $chn_rech = $chaine;
    $exist = FALSE;

    if (($sequence <> '') AND ($chaine <> '')) {
        $tab_seq = explode('-', $sequence);

        foreach ($tab_seq as $chn_seq) {
            if ($chn_rech == $chn_seq) {
                $exist = TRUE;
            }
        }
    }
    return $exist;
}

/**
 * Vérifie si un texte existe dans un tableau de textes
 *
 * @param $texte
 * @param $tabtxt
 *
 * @return bool
 */
function exist_in_array($texte, $tabtxt)
{
    $exist = FALSE;

    if (count($tabtxt) > 0) {
        foreach ($tabtxt as $txt_found) {
            if ($texte == $txt_found) {
                $exist = TRUE;
                break;
            }
        }
    }

    return $exist;
}

/**
 * Vérifie si au moins 2 textes sont identiques à l'intérieur de 2 tableaux de textes
 *
 * @param $tabtxt1
 * @param $tabtxt2
 *
 * @return bool
 */
function txt_commun_in_2tabtxt($tabtxt1, $tabtxt2)
{
    $txt_tab1 = $tabtxt1;
    $txt_tab2 = $tabtxt2;
    $exist = FALSE;

    foreach ($txt_tab1 as $txt_found) {
        if (exist_in_array($txt_found, $txt_tab2) == TRUE) {
            $exist = TRUE;
        }
    }

    return $exist;
}

/**
 * Retourne un tableau contenant les textes différents entre 2 tableaux de textes
 *
 * @param $tabtxt1
 * @param $tabtxt2
 *
 * @return mixed
 */
function diff_txt_in_tabtxt($tabtxt1, $tabtxt2)
{
    $txt_tab1 = $tabtxt1;
    $txt_tab2 = $tabtxt2;

    $i = 0;

    if (is_array($txt_tab1) == TRUE) {
        foreach ($txt_tab1 as $txt_found1) {
            $exist = FALSE;
            foreach ($txt_tab2 as $txt_found2) {
                if ($txt_found1 == $txt_found2) {
                    $exist = TRUE;
                }

                if ($exist == FALSE) {
                    $tab_diff[$i] = $txt_found2;
                    $i++;
                }
            }
        }
    }

    return $tab_diff;
}

/**
 * Convertion d'une chaine pour être correctement stockée sur le serveur
 *
 * @param $texte
 *
 * @return mixed|string
 */
function str_upload($texte)
{
    $nom_upload = str_majuscules($texte);
    $nom_upload = strtolower($nom_upload);
    $nom_upload = strtr($nom_upload, 'ÀÁÂÃÄÅÇÈÉÊËÌÍÎÏÒÓÔÕÖÙÚÛÜÝàáâãäåçèéêëìíîïðòóôõöùúûüýÿ', 'AAAAAACEEEEIIIIOOOOOUUUUYaaaaaaceeeeiiiioooooouuuuyy');
    $nom_upload = preg_replace('/([^.a-z0-9]+)/i', '_', $nom_upload);

    // $nom_upload = strtr($nom_upload," ","_");

    return $nom_upload;
}

/**
 * Vérifie un texte est bien une adresse email
 *
 * @param $texte
 *
 * @return bool
 */
function is_email($texte)
{
    if (!preg_match("/^[a-z0-9_\-]+(\.[a-z0-9_\-]+)*@[a-z0-9\-]*[a-z0-9](\.[a-z0-9\-]*[a-z0-9])*[\.][a-z]{2,3}$/", $texte)) {
        return FALSE;
    } else {
        return TRUE;
    }
}

if (!function_exists('htmlspecialchars_decode')) {
    /**
     * Nettoyage des encode_chars
     *
     * @param $string
     * @param int $quote_style
     * @return string
     */
    function htmlspecialchars_decode($string, $quote_style = ENT_COMPAT)
    {
        return strtr($string, array_flip(get_html_translation_table(HTML_SPECIALCHARS, $quote_style)));
    }
}


/**
 * Encodage UTF-8
 *
 * @param $str
 * @return string
 */
function utf8_encode2($str)
{
    $arr1 = str_split($str);
    $newstr = '';
    foreach ($arr1 as $value) {
        switch (hexdec(bin2hex($value))) {
            case 128 :
                $newstr .= '€';
                break;
            case 131 :
                $newstr .= 'ƒ';
                break;
            case 132 :
                $newstr .= '„';
                break;
            case 133 :
                $newstr .= '…';
                break;
            case 134 :
                $newstr .= '†';
                break;
            case 135 :
                $newstr .= '‡';
                break;
            case 136 :
                $newstr .= 'ˆ';
                break;
            case 137 :
                $newstr .= '‰';
                break;
            case 138 :
                $newstr .= 'Š';
                break;
            case 139 :
                $newstr .= '‹';
                break;
            case 140 :
                $newstr .= 'Œ';
                break;
            case 142 :
                $newstr .= 'Ž';
                break;
            case 145 :
                $newstr .= '‘';
                break;
            case 146 :
                $newstr .= '’';
                break;
            case 147 :
                $newstr .= '“';
                break;
            case 148 :
                $newstr .= '”';
                break;
            case 149 :
                $newstr .= '•';
                break;
            case 150 :
                $newstr .= '–';
                break;
            case 151 :
                $newstr .= '—';
                break;
            case 152 :
                $newstr .= '˜';
                break;
            case 153 :
                $newstr .= '™';
                break;
            case 154 :
                $newstr .= 'š';
                break;
            case 155 :
                $newstr .= '›';
                break;
            case 156 :
                $newstr .= 'œ';
                break;
            case 158 :
                $newstr .= 'ž';
                break;
            case 159 :
                $newstr .= 'Ÿ';
                break;
            default :
                $newstr .= utf8_encode($value);
                break;
        }
    }

    return $newstr;
}

/**
 * Encodage UTF-8 (y compris tableaux)
 *
 * @param $value
 * @return array|string
 */

function encode_str2($value)
{
    return is_array($value) ? array_map('encode_str2', $value) : utf8_encode2($value);
}

/**
 * Encodage en UTF8
 * On n'encode pas si la collation MySQL est déjà en UTF8
 *
 * @param $value
 *
 * @return array|string
 */
function encode_str($value)
{
    // return is_array($value) ? array_map('encode_str', $value) : addcslashes($value,'"');

    return escape_doublequotes($value);
}


/**
 * Décodage de l'UTF8
 * On ne décode pas si le SETNAMES est déjà en UTF8
 *
 * @param $txt
 * @return string
 */
function trans($txt)
{
    //echo 'txt : '.$txt.'<br>';
    /*
    if (!preg_match("/[\200-\237]/", $txt)
        && !preg_match("/[\241-\377]/", $txt)
    ) {
        return $txt;
    }

    // decode three byte unicode characters
    $string = preg_replace("/([\340-\357])([\200-\277])([\200-\277])/e",
        "'&#'.((ord('\\1')-224)*4096 + (ord('\\2')-128)*64 + (ord('\\3')-128)).';'",
        $txt
    );
    // decode two byte unicode characters
    $string = preg_replace("/([\300-\337])([\200-\277])/e",
        "'&#'.((ord('\\1')-192)*64+(ord('\\2')-128)).';'",
        $txt
    );
    //echo 'str : '.$string.'<br>';
    return $string;
    */
    //return iconv('UTF-8', 'CP1252', $txt)
    if (iconv('UTF-8', 'ISO-8859-15', $txt)) {
        return $txt;
    } else {
        return iconv('UTF-8', 'ISO-8859-15//TRANSLIT', $txt);
    }
}


/**
 * Décodage en UTF8
 * On ne décode pas si la collation MySQL est déjà en UTF8
 *
 * @param $value
 *
 * @return array|string
 */
function decode_str($value)
{
    return is_array($value) ? array_map('decode_str', $value) : trans($value);
}

/**
 * Echappement des caractères
 *
 * @param $str
 *
 * @return array|string
 */
function str_escape($str)
{
    if (is_array($str)) // Si la variable passée en argument est un array, on appelle la fonction str_escape dessus
    {
        return array_map('str_escape', $str);
    } else // Sinon, nettoyage de la chaîne
    {
        return addslashes($str);
    }
}

/**
 * Echappement des ' seuls (pas les ")
 *
 * @param $str
 *
 * @return array|mixed
 */
function escape_quotes($str)
{
    if (is_array($str)) // Si la variable passée en argument est un array, on appelle la fonction str_escape dessus
    {
        return array_map('escape_quotes', $str);
    } else // Sinon, nettoyage de la chaîne
    {
        $str = preg_replace("/[\\/]+/", '/', $str);
    }
    return $str;
}

/**
 * Echappement des " seuls (pas les ')
 *
 * @param $str
 *
 * @return array|mixed
 */
function escape_doublequotes($str)
{
    if (is_array($str)) // Si la variable passée en argument est un array, on appelle la fonction str_escape dessus
    {
        return array_map('escape_doublequotes', $str);
    } else // Sinon, nettoyage de la chaîne
    {
        $str = preg_replace("/\"/", '&quot;', $str);
    }
    return $str;
}

/**
 * Nettoyage de chaine de caractères
 *
 * @param $value
 *
 * @return array|string
 */
function strip_tags_deep($value)
{
    return is_array($value) ? array_map('strip_tags_deep', $value) : strip_tags($value);
}

/**
 * Nettoyage de chaine de caractères sur htmlspecialchars
 *
 * @param $value
 *
 * @return array|string
 */
function htmlspecialchars_decode_deep($value)
{
    return is_array($value) ? array_map('htmlspecialchars_decode_deep', $value) : htmlspecialchars_decode($value,ENT_COMPAT);
}



/**
 * Nettoyage des chaines (notamment INPUT)
 * $decode : si true : on décode l'UTF-8 (utile pour enregistrements MySQL)
 *
 * @param      $value
 * @param bool $decode
 *
 * @return array|string
 */
function clean_str($value, $decode = TRUE)
{
    $str_cleaned = $value;
    if ($decode == TRUE) {
        $str_cleaned = decode_str($value);
    }
    $str_cleaned = strip_tags_deep($str_cleaned);
    $str_cleaned = htmlspecialchars_decode_deep($str_cleaned);
    return $str_cleaned;
}

/**
 * Formate un nombre
 *
 * @param $number
 * @param $decimal
 *
 * @return string
 */
function format_num($number, $decimal)
{
    global
    $_SESSION;

    $str = $number;

    switch (strtolower($_SESSION['lng'])) {
        case 'fr' :
            $str = number_format((float)$number, (int)$decimal, '.', '');
            break;
    }

    return $str;
}

/**
 * Formatage complet d'un nombre en fonction des paramètres de session
 *
 * @param $number
 * @param string $tag
 * @param string $id
 * @param bool $devise
 * @param string $pays
 * @param bool $open
 * @param bool $inPDF
 * @return string
 */
function full_num_format($number, $tag = '', $id = '', $devise = FALSE, $pays = '', $open = TRUE, $inPDF = FALSE)
{
    global
    $db,
    $_SESSION;

    $code_TXT = '';
    if (trim($pays) <> '') {
        $codepays = $pays;
    } else {
        $codepays = $_SESSION['codepays'];
    }
    $str = '';
    $pays_nbdec = (int)valsession('num_nbdec');
    $pays_cardec = $_SESSION['num_cardec'];
    $pays_carsep = $_SESSION['num_carsep'];

    if ($open == TRUE) {
        $db = open_database(DBUSER, DBPASS, DBNAME, DBHOST, 'utf8');
    }
    // On récupère le code devise du pays
    $rech = 'SELECT * FROM `' . TBPAYS . "` WHERE `pays_code` = '" . $db->escape($codepays) . "'";
    $row = $db->get_row($rech, ARRAY_A);
    if ($row) {
        $row = encode_str($row);
        extract($row);
        // On récupère le texte devise
        if ($pays_codeadev <> 'EUR') // Si 'EUR' (Euro), il faut coder en HTML car le symbole '€' n'est pas correctement géré en UTF-8
        {
            $rech2 = 'SELECT dev_symtxt FROM `' . TBDEV . "` WHERE dev_codea = '" . $db->escape($pays_codeadev) . "'";
            $row2 = $db->get_row($rech2, ARRAY_A);
            if ($row2) {
                $row2 = encode_str($row2);
                extract($row2);
                $code_TXT = $pays_codeadev;
                if (trim($dev_symtxt) <> '') {
                    $code_TXT = $dev_symtxt;
                }
            }
        } else {
            if ($inPDF == TRUE) {
                $code_TXT = chr(128);
            } else {
                $code_TXT = utf8_encode('&#8364;');
            }
            //$code_TXT = '&euro;';
        }
    }
    if ($open == TRUE) {
        close_database();
    }
    if ($devise == TRUE) {
        if ($pays_devpos == 'L') {
            $str .= utf8_encode($code_TXT) . ' ';
        }
    }

    if ($tag <> '') {
        $str .= '<' . $tag;
    }
    if ($id <> '') {
        $str .= ' id ="' . $id . '"';
    }
    if ($tag <> '') {
        $str .= '>';
    }
    if ($inPDF == FALSE) {
        $str .= number_format((float)$number, (int)$pays_nbdec, $pays_cardec, $pays_carsep);
    } else {
        if ($number <> '') {
            $str .= number_format((float)$number, (int)$pays_nbdec, $pays_cardec, $pays_carsep);
        }
    }
    if ($tag <> '') {
        $str .= '</' . $tag . '>';
    }
    if ($devise == TRUE) {
        if ($pays_devpos == 'R') {
            $str .= ' ' . utf8_encode($code_TXT);
        }
    }

    return $str;
}

/**
 * Retourne un caractère ASCII (1 = 'A')
 *
 * @param $num
 *
 * @return string
 */
function numtochar($num)
{
    $str = '';

    if (($num >= 1) AND ($num <= 26)) {
        $str = chr(($num - 1) + 65);
    }
    return $str;
}

/**
 * Construction message erreur
 *
 * @param      $msg
 * @param bool $return
 *
 * @return string
 */
function give_mess($msg, $return = FALSE)
{
    if ($return == TRUE) {
        return $msg . '<br />';
    } else {
        return $msg;
    }
}


/**
 * Retourne la string regexp 'téléphone fixe' en fonction du code pays
 * Si pas de pays, numéro international
 *
 * @param $pays
 *
 * @return string
 */
function GiveExpr_tel($pays)
{
    if (trim($pays) <> '') {
        $pays = strtolower($pays);

        switch ($pays) {
            case 'ad' :
                $expr = "^([+]376[ ])?[0-9]{6,9}$";
                break;
            case 'ae' :
                $expr = "^([+]31[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{7,9}$";
                break;
            case 'af' :
                $expr = "^([+]93[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'ag' :
                $expr = "^([+]1[ ])?268[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'ai' :
                $expr = "^([+]1[ ])?264[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'al' :
                $expr = "^([+]355[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{4,6}?$";
                break;
            case 'am' :
                $expr = "^([+]374[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,6}$";
                break;
            case 'an' :
                $expr = "^([+]599[ ]|0)[0-9]{0,1}[ \.\-]?[0-9]{7}$";
                break;
            case 'ao' :
                $expr = "^([+]244[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'ar' :
                $expr = "^([+]54[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'as' :
                $expr = "^([+]1[ ])?684[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'at' :
                $expr = "^([+]43[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,12}$";
                break;
            case 'au' :
                $expr = "^([+]61[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,15}$";
                break;
            case 'aw' :
                $expr = "^([+]297[ ])?[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'ax' :
                $expr = "^([+]358[ ])?18[ \.\-]??[0-9]{4}([0-9]{6})?$";
                break;
            case 'az' :
                $expr = "^([+]994[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ba' :
                $expr = "^([+]387[ ]|0)[0-9]{2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'bb' :
                $expr = "^([+]1[ ])?246[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bd' :
                $expr = "^([+]880[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'be' :
                $expr = "^([+]32[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'bf' :
                $expr = "^([+]226[ ])?[0-9]{8}$";
                break;
            case 'bg' :
                $expr = "^([+]359[ ]|0)[0-9]{1,5}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'bh' :
                $expr = "^([+]973[ ])?[0-9]{6,8}$";
                break;
            case 'bi' :
                $expr = "^([+]257[ ])?[0-9]{7}$";
                break;
            case 'bj' :
                $expr = "^([+]229[ ])?[0-9]{8}$";
                break;
            case 'bm' :
                $expr = "^([+]1[ ])?441[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bn' :
                $expr = "^([+]673[ ])?[0-9]{6,7}$";
                break;
            case 'bo' :
                $expr = "^([+]49[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'br' :
                $expr = "^([+]55[ ]|0)[0-9]{2}[ \.\-]?[0-9]{8}$";
                break;
            case 'bs' :
                $expr = "^([+]1[ ])?242[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bt' :
                $expr = "^([+]975[ ]|0)?[0-9]{1}[ \.\-]?[0-9]{6}$";
                break;
            case 'bw' :
                $expr = "^([+]267[ ])?[0-9]{6,7}$";
                break;
            case 'by' :
                $expr = "^([+]375[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'bz' :
                $expr = "^([+]501[ ])?[0-9]{7}$";
                break;
            case 'ca' :
                $expr = "^([+]1[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'cd' :
                $expr = "^([+]243[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'cf' :
                $expr = "^([+]236[ ])?[0-9]{6}$";
                break;
            case 'cg' :
                $expr = "^([+]242[ ])?[0-9]{7}$";
                break;
            case 'ch' :
                $expr = "^([+]41[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'ci' :
                $expr = "^([+]225[ ])?[0-9]{8}$";
                break;
            case 'ck' :
                $expr = "^([+]682[ ])?[0-9]{5}$";
                break;
            case 'cl' :
                $expr = "^([+]56[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'cm' :
                $expr = "^([+]237[ ])?[0-9]{7}$";
                break;
            case 'cn' :
                $expr = "^([+]86[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'co' :
                $expr = "^([+]57[ ]|09)[0-9]{1,5}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'cr' :
                $expr = "^([+]506[ ])?[0-9]{7}$";
                break;
            case 'cs' :
                $expr = "^([+]381[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'cu' :
                $expr = "^([+]53[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'cv' :
                $expr = "^([+]238[ ])?[0-9]{7}$";
                break;
            case 'cz' :
                $expr = "^([+]420[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{3}$";
                break;
            case 'cy' :
                $expr = "^([+]357[ ])?[0-9]{1,2}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'de' :
                $expr = "^([+]49[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,9}$";
                break;
            case 'dj' :
                $expr = "^([+]253[ ])?[0-9]{6}$";
                break;
            case 'dk' :
                $expr = "^([+]45[ ])?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'do' :
                $expr = "^([+]1[ ])?767[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'dz' :
                $expr = "^([+]213[ ]|0)[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'ec' :
                $expr = "^([+]49[ ]|0)[0-9]{1}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'ee' :
                $expr = "^([+]372[ ])?[0-9]{7,8}$";
                break;
            case 'eg' :
                $expr = "^([+]20[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'er' :
                $expr = "^([+]291[ ]|0)[0-9]{1}[ \.\-]?[0-9]{6}$";
                break;
            case 'es' :
                $expr = "^([+]34[ ])?[0-9]{9}$";
                break;
            case 'et' :
                $expr = "^([+]251[ ]|0)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'fi' :
                $expr = "^([+]358[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,9}$";
                break;
            case 'fj' :
                $expr = "^([+]679[ ])?[0-9]{7}$";
                break;
            case 'fk' :
                $expr = "^([+]500[ ])?[0-9]{5}$";
                break;
            case 'fm' :
                $expr = "^([+]691[ ]|1)[0-9]{7}$";
                break;
            case 'fo' :
                $expr = "^([+]298[ ])?[0-9]{6}$";
                break;
            case 'fr' :
                $expr = "^([+]33[ ]|0)[1-6,8-9]{1}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'ga' :
                $expr = "^([+]241[ ])?[0-9]{6}$";
                break;
            case 'gb' :
                $expr = "^([+]44[ ]|0)[0-9]{2,6}[ \.\-]?[0-9]{3,8}$";
                break;
            case 'gd' :
                $expr = "^([+]1[ ])?473[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'ge' :
                $expr = "^([+]995[ ]|8)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'gf' :
                $expr = "^([+]594[ ])?[1-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'gh' :
                $expr = "^([+]233[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{3,6}$";
                break;
            case 'gi' :
                $expr = "^([+]350[ ])?[0-9]{4,8}$";
                break;
            case 'gl' :
                $expr = "^([+]299[ ])?[0-9]{6}$";
                break;
            case 'gm' :
                $expr = "^([+]220[ ])?[0-9]{7}$";
                break;
            case 'gn' :
                $expr = "^([+]224[ ])?[0-9]{6}$";
                break;
            case 'gp' :
                $expr = "^([+]590[ ]|0)[1-9]{1}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'gq' :
                $expr = "^([+]240[ ])?[0-9]{0,1}[ \.\-]?[0-9]{6}$";
                break;
            case 'gr' :
                $expr = "^([+]30[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'gt' :
                $expr = "^([+]502[ ])?[0-9]{7,8}$";
                break;
            case 'gu' :
                $expr = "^([+]1[ ])?671[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'gw' :
                $expr = "^([+]245[ ])?[0-9]{6}$";
                break;
            case 'gy' :
                $expr = "^([+]591[ ])?[0-9]{1}[ \.\-]?[0-9]{5}$";
                break;
            case 'hk' :
                $expr = "^([+]852[ ])?[0-9]{8}$";
                break;
            case 'hn' :
                $expr = "^([+]504[ ])?[0-9]{7}$";
                break;
            case 'hr' :
                $expr = "^([+]385[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ht' :
                $expr = "^([+]509[ ])?[0-9]{7}$";
                break;
            case 'hu' :
                $expr = "^([+]36[ ]|06)?[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'id' :
                $expr = "^([+]62[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{5,11}$";
                break;
            case 'ie' :
                $expr = "^([+]353[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'il' :
                $expr = "^([+]972[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'in' :
                $expr = "^([+]91[ ]|0)[0-9]{2,7}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'iq' :
                $expr = "^([+]964[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,9}$";
                break;
            case 'ir' :
                $expr = "^([+]97[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;
            case 'is' :
                $expr = "^([+]354[ ])?[0-9]{7,9}$";
                break;
            case 'it' :
                $expr = "^([+]39[ ])?[0-9]{1,3}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'jm' :
                $expr = "^([+]1[ ])?876[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'jo' :
                $expr = "^([+]962[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7,8}$";
                break;
            case 'jp' :
                $expr = "^([+]81[ ]|0)[0-9]{1,5}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'ke' :
                $expr = "^([+]254[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'kg' :
                $expr = "^([+]996[ ]|0)[0-9]{3,4}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'kh' :
                $expr = "^([+]855[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'ki' :
                $expr = "^([+]686[ ])?[0-9]{5}$";
                break;
            case 'km' :
                $expr = "^([+]262[ ]|[+]269[ ])?[0-9]{6}$";
                break;
            case 'kn' :
                $expr = "^([+]1[ ])?869[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'kp' :
                $expr = "^([+]82[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'kr' :
                $expr = "^([+]850[ ]|0)?[0-9]{1,2}[ \.\-]?[0-9]{7}$";
                break;
            case 'ky' :
                $expr = "^([+]1[ ])?345[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'kw' :
                $expr = "^([+]965[ ])?[0-9]{7}$";
                break;
            case 'kz' :
                $expr = "^([+]7[ ]|8)[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'la' :
                $expr = "^([+]856[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'lb' :
                $expr = "^([+]961[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6}$";
                break;
            case 'lc' :
                $expr = "^([+]1[ ])?758[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'li' :
                $expr = "^([+]423[ ])?[0-9]{7}$";
                break;
            case 'lk' :
                $expr = "^([+]94[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'lr' :
                $expr = "^([+]231[ ])?[0-9]{6}$";
                break;
            case 'ls' :
                $expr = "^([+]266[ ])?[0-9]{8}$";
                break;
            case 'lt' :
                $expr = "^([+]370[ ]|0|8)[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'lu' :
                $expr = "^([+]352[ ])?[0-9]{5,11}$";
                break;
            case 'lv' :
                $expr = "^([+]371[ ]|8)?[0-9]{0,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ly' :
                $expr = "^([+]218[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ma' :
                $expr = "^([+]212[ ]|0)[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'mc' :
                $expr = "^([+]377[ ])?[0-9]{8,9}$";
                break;
            case 'md' :
                $expr = "^([+]373[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'me' :
                $expr = "^([+]382[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'mg' :
                $expr = "^([+]261[ ])?([0-9]{2})?[0-9]{7}$";
                break;
            case 'mh' :
                $expr = "^([+]692[ ])?[1]{0,1}[ \.\-]?[0-9]{7}$";
                break;
            case 'mk' :
                $expr = "^([+]389[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ml' :
                $expr = "^([+]223[ ])?[0-9]{7}$";
                break;
            case 'mm' :
                $expr = "^([+]95[ ]|0)?[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'mn' :
                $expr = "^([+]976[ ]|01|02)[0-9]{1,4}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'mo' :
                $expr = "^([+]853[ ])?[0-9]{6,7}$";
                break;
            case 'mp' :
                $expr = "^([+]1[ ])?670[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'mq' :
                $expr = "^([+]596[ ])?[1-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'mr' :
                $expr = "^([+]222[ ])?[0-9]{7}$";
                break;
            case 'ms' :
                $expr = "^([+]1[ ])?664[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'mt' :
                $expr = "^([+]356[ ])?[0-9]{2}[ \.\-][0-9]{3}[ \.\-][0-9]{3}$";
                break;
            case 'mu' :
                $expr = "^([+]230[ ])?[0-9]{7}$";
                break;
            case 'mv' :
                $expr = "^([+]960[ ])?[0-9]{7}$";
                break;
            case 'mw' :
                $expr = "^([+]265[ ])?[0-9]{8}$";
                break;
            case 'mx' :
                $expr = "^([+]52[ ]|01|02)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'my' :
                $expr = "^([+]60[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'mz' :
                $expr = "^([+]258[ ])?[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'na' :
                $expr = "^([+]264[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{2,6}$";
                break;
            case 'nc' :
                $expr = "^([+]687[ ])?[0-9]{6}$";
                break;
            case 'ne' :
                $expr = "^([+]227[ ])?[0-9]{6}$";
                break;
            case 'ng' :
                $expr = "^([+]233[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ni' :
                $expr = "^([+]505[ ])?[0-9]{7}$";
                break;
            case 'nl' :
                $expr = "^([+]31[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'np' :
                $expr = "^([+]977[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'nr' :
                $expr = "^([+]674[ ])?[0-9]{7}$";
                break;
            case 'nu' :
                $expr = "^([+]683[ ])?[0-9]{4}$";
                break;
            case 'pa' :
                $expr = "^([+]507[ ])?[0-9]{7}$";
                break;
            case 'pf' :
                $expr = "^([+]689[ ])?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'pr' :
                $expr = "^([+]1[ ])?[787|939][ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'nf' :
            case 'pn' :
                $expr = "^([+]672[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{3,5}$";
                break;
            case 'no' :
                $expr = "^([+]47[ ])?[0-9]{8}$";
                break;
            case 'nz' :
                $expr = "^([+]64[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'om' :
                $expr = "^([+]968[ ])?[0-9]{6,8}$";
                break;
            case 'pe' :
                $expr = "^([+]51[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'pg' :
                $expr = "^([+]675[ ])?[0-9]{7}$";
                break;
            case 'ph' :
                $expr = "^([+]63[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'pk' :
                $expr = "^([+]92[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'pl' :
                $expr = "^([+]48[ ]|0)[0-9]{2}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'pm' :
                $expr = "^([+]508[ ])?[0-9]{6}$";
                break;
            case 'ps' :
                $expr = "^([+]970[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'pt' :
                $expr = "^([+]351[ ])?[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'pw' :
                $expr = "^([+]680[ ])?[0-9]{7}$";
                break;
            case 'py' :
                $expr = "^([+]595[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'qa' :
                $expr = "^([+]974[ ])?[0-9]{6}$";
                break;
            case 'ro' :
                $expr = "^([+]40[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ru' :
                $expr = "^([+]7[ ]|8)[0-9]{3,5}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'rw' :
                $expr = "^([+]250[ ])?[0-9]{5,8}$";
                break;
            case 'sa' :
                $expr = "^([+]966[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'sc' :
                $expr = "^([+]248[ ])?[0-9]{6}$";
                break;
            case 'sd' :
                $expr = "^([+]249[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'sk' :
                $expr = "^([+]421[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{7,8}$";
                break;
            case 're' :
                $expr = "^([+]262[ ])?[0-9]{10}$";
                break;
            case 'sb' :
                $expr = "^([+]677[ ])?[0-9]{5}$";
                break;
            case 'se' :
                $expr = "^([+]46[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'sg' :
                $expr = "^([+]65[ ])?[0-9]{7,8}$";
                break;
            case 'sh' :
                $expr = "^([+]290[ ])?[0-9]{4}$";
                break;
            case 'si' :
                $expr = "^([+]386[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'sl' :
                $expr = "^([+]232[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'sm' :
                $expr = "^([+]378[ ])?[0-9]{10,12}$";
                break;
            case 'sn' :
                $expr = "^([+]221[ ])?[0-9]{7}$";

                break;
            case 'so' :
                $expr = "^([+]252[ ])?[0-9]{7}$";
                break;
            case 'sr' :
                $expr = "^([+]597[ ])?[0-9]{6}$";
                break;
            case 'st' :
                $expr = "^([+]239[ ])?[0-9]{6}$";
                break;
            case 'sv' :
                $expr = "^([+]503[ ])?[0-9]{7}$";
                break;
            case 'sy' :
                $expr = "^([+]963[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'sz' :
                $expr = "^([+]268[ ]|0)[0-9]{7}$";
                break;
            case 'tc' :
                $expr = "^([+]1[ ])?649[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'td' :
                $expr = "^([+]235[ ])?[0-9]{6}$";
                break;
            case 'th' :
                $expr = "^([+]66[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'tg' :
                $expr = "^([+]228[ ])?[0-9]{7}$";
                break;
            case 'tj' :
                $expr = "^([+]998[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'tk' :
                $expr = "^([+]690[ ])?[0-9]{1}[ \.\-]?[0-9]{3}$";
                break;
            case 'tl' :
                $expr = "^([+]670[ ])?[0-9]{7}$";
                break;
            case 'tm' :
                $expr = "^([+]993[ ]|8)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'tn' :
                $expr = "^([+]216[ ]|0)[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'to' :
                $expr = "^([+]676[ ])?[0-9]{7}$";
                break;
            case 'tr' :
                $expr = "^([+]90[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;
            case 'tt' :
                $expr = "^([+]1[ ])?868[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'tv' :
                $expr = "^([+]688[ ])?[0-9]{5}$";
                break;
            case 'tw' :
                $expr = "^([+]886[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'tz' :
                $expr = "^([+]255[ ]|0)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'ua' :
                $expr = "^([+]380[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ug' :
                $expr = "^([+]256[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'us' :
                $expr = "^([+]1[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'uy' :
                $expr = "^([+]598[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'uz' :
                $expr = "^([+]998[ ]|8)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'vc' :
                $expr = "^([+]1[ ])?784[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 've' :
                $expr = "^([+]58[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;
            case 'vg' :
                $expr = "^([+]1[ ])?284[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'vi' :
                $expr = "^([+]1[ ])?340[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'vn' :
                $expr = "^([+]84[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'vu' :
                $expr = "^([+]678[ ])?[0-9]{5}$";
                break;
            case 'wf' :
                $expr = "^([+]681[ ])?[0-9]{6}$";
                break;
            case 'ws' :
                $expr = "^([+]685[ ])?[0-9]{6,7}$";
                break;
            case 'ye' :
                $expr = "^([+]967[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'yt' :
                $expr = "^([+]262[ ]|[+]269[ ])?[0-9]{10}$";
                break;
            case 'za' :
                $expr = "^([+]27[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'zm' :
                $expr = "^([+]260[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'zw' :
                $expr = "^([+]263[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,8}$";
                break;
            default :
                $expr = "^([+][0-9]{2,3}[ ])?[0-9]{6,11}$";
                break;
        }
    } else {
        $expr = "^([+][0-9]{2,3}[ ])?[0-9]{6,11}$";
    }
    return $expr;
}

/**
 * Retourne la string regexp 'téléphone portable' en fonction du code pays
 * Si pas de pays, numéro international
 *
 * @param $pays
 *
 * @return string
 */
function GiveExpr_telp($pays)
{
    if (trim($pays) <> '') {
        $pays = strtolower($pays);

        switch ($pays) {
            case 'ad' :
                $expr = "^([+]376[ ])?[0-9]{6,9}$";
                break;
            case 'ae' :
                $expr = "^([+]31[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{7,9}$";
                break;
            case 'af' :
                $expr = "^([+]93[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'ag' :
                $expr = "^([+]1[ ])?268[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'ai' :
                $expr = "^([+]1[ ])?264[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'al' :
                $expr = "^([+]355[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{4,6}?$";
                break;
            case 'am' :
                $expr = "^([+]374[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,6}$";
                break;
            case 'an' :
                $expr = "^([+]599[ ]|0)[0-9]{0,1}[ \.\-]?[0-9]{7}$";
                break;
            case 'ao' :
                $expr = "^([+]244[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'ar' :
                $expr = "^([+]54[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'as' :
                $expr = "^([+]1[ ])?684[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'at' :
                $expr = "^([+]43[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,12}$";
                break;
            case 'au' :
                $expr = "^([+]61[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,15}$";
                break;
            case 'aw' :
                $expr = "^([+]297[ ])?[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'ax' :
                $expr = "^([+]358[ ])?18[ \.\-]??[0-9]{4}([0-9]{6})?$";
                break;
            case 'az' :
                $expr = "^([+]994[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ba' :
                $expr = "^([+]387[ ]|0)[0-9]{2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'bb' :
                $expr = "^([+]1[ ])?246[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bd' :
                $expr = "^([+]880[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'be' :
                $expr = "^([+]32[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'bf' :
                $expr = "^([+]226[ ])?[0-9]{8}$";
                break;
            case 'bg' :
                $expr = "^([+]359[ ]|0)[0-9]{1,5}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'bh' :
                $expr = "^([+]973[ ])?[0-9]{6,8}$";
                break;
            case 'bi' :
                $expr = "^([+]257[ ])?[0-9]{7}$";
                break;
            case 'bj' :
                $expr = "^([+]229[ ])?[0-9]{8}$";
                break;
            case 'bm' :
                $expr = "^([+]1[ ])?441[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bn' :
                $expr = "^([+]673[ ])?[0-9]{6,7}$";
                break;
            case 'bo' :
                $expr = "^([+]49[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'br' :
                $expr = "^([+]55[ ]|0)[0-9]{2}[ \.\-]?[0-9]{8}$";
                break;
            case 'bs' :
                $expr = "^([+]1[ ])?242[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'bt' :
                $expr = "^([+]975[ ]|0)?[0-9]{1}[ \.\-]?[0-9]{6}$";
                break;
            case 'bw' :
                $expr = "^([+]267[ ])?[0-9]{6,7}$";
                break;
            case 'by' :
                $expr = "^([+]375[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'bz' :
                $expr = "^([+]501[ ])?[0-9]{7}$";
                break;
            case 'ca' :
                $expr = "^([+]1[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'cd' :
                $expr = "^([+]243[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'cf' :
                $expr = "^([+]236[ ])?[0-9]{6}$";
                break;
            case 'cg' :
                $expr = "^([+]242[ ])?[0-9]{7}$";
                break;
            case 'ch' :
                $expr = "^([+]41[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'ci' :
                $expr = "^([+]225[ ])?[0-9]{8}$";
                break;
            case 'ck' :
                $expr = "^([+]682[ ])?[0-9]{5}$";
                break;
            case 'cl' :
                $expr = "^([+]56[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'cm' :
                $expr = "^([+]237[ ])?[0-9]{7}$";
                break;
            case 'cn' :
                $expr = "^([+]86[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'co' :
                $expr = "^([+]57[ ]|09)[0-9]{1,5}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'cr' :
                $expr = "^([+]506[ ])?[0-9]{7}$";
                break;
            case 'cs' :
                $expr = "^([+]381[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'cu' :
                $expr = "^([+]53[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'cv' :
                $expr = "^([+]238[ ])?[0-9]{7}$";
                break;
            case 'cz' :
                $expr = "^([+]420[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{3}$";
                break;
            case 'cy' :
                $expr = "^([+]357[ ])?[0-9]{1,2}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'de' :
                $expr = "^([+]49[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,9}$";
                break;
            case 'dj' :
                $expr = "^([+]253[ ])?[0-9]{6}$";
                break;
            case 'dk' :
                $expr = "^([+]45[ ])?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'do' :
                $expr = "^([+]1[ ])?767[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'dz' :
                $expr = "^([+]213[ ]|0)[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'ec' :
                $expr = "^([+]49[ ]|0)[0-9]{1}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'ee' :
                $expr = "^([+]372[ ])?[0-9]{7,8}$";
                break;
            case 'eg' :
                $expr = "^([+]20[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'er' :
                $expr = "^([+]291[ ]|0)[0-9]{1}[ \.\-]?[0-9]{6}$";
                break;
            case 'es' :
                $expr = "^([+]34[ ])?[0-9]{9}$";
                break;
            case 'et' :
                $expr = "^([+]251[ ]|0)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'fi' :
                $expr = "^([+]358[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,9}$";
                break;
            case 'fj' :
                $expr = "^([+]679[ ])?[0-9]{7}$";
                break;
            case 'fk' :
                $expr = "^([+]500[ ])?[0-9]{5}$";
                break;
            case 'fm' :
                $expr = "^([+]691[ ]|1)[0-9]{7}$";
                break;
            case 'fo' :
                $expr = "^([+]298[ ])?[0-9]{6}$";
                break;
            case 'fr' :
                $expr = "^([+]33[ ]|0)6[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'ga' :
                $expr = "^([+]241[ ])?[0-9]{6}$";
                break;
            case 'gb' :
                $expr = "^([+]44[ ]|0)[0-9]{2,6}[ \.\-]?[0-9]{3,8}$";
                break;
            case 'gd' :
                $expr = "^([+]1[ ])?473[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'ge' :
                $expr = "^([+]995[ ]|8)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'gf' :
                $expr = "^([+]594[ ])?[1-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'gh' :
                $expr = "^([+]233[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{3,6}$";
                break;
            case 'gi' :
                $expr = "^([+]350[ ])?[0-9]{4,8}$";
                break;
            case 'gl' :
                $expr = "^([+]299[ ])?[0-9]{6}$";
                break;
            case 'gm' :
                $expr = "^([+]220[ ])?[0-9]{7}$";
                break;
            case 'gn' :
                $expr = "^([+]224[ ])?[0-9]{6}$";
                break;
            case 'gp' :
                $expr = "^([+]590[ ]|0)[1-9]{1}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'gq' :
                $expr = "^([+]240[ ])?[0-9]{0,1}[ \.\-]?[0-9]{6}$";
                break;
            case 'gr' :
                $expr = "^([+]30[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'gt' :
                $expr = "^([+]502[ ])?[0-9]{7,8}$";
                break;
            case 'gu' :
                $expr = "^([+]1[ ])?671[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'gw' :
                $expr = "^([+]245[ ])?[0-9]{6}$";
                break;
            case 'gy' :
                $expr = "^([+]591[ ])?[0-9]{1}[ \.\-]?[0-9]{5}$";
                break;
            case 'hk' :
                $expr = "^([+]852[ ])?[0-9]{8}$";
                break;
            case 'hn' :
                $expr = "^([+]504[ ])?[0-9]{7}$";
                break;
            case 'hr' :
                $expr = "^([+]385[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ht' :
                $expr = "^([+]509[ ])?[0-9]{7}$";
                break;
            case 'hu' :
                $expr = "^([+]36[ ]|06)?[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'id' :
                $expr = "^([+]62[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{5,11}$";
                break;
            case 'ie' :
                $expr = "^([+]353[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'il' :
                $expr = "^([+]972[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'in' :
                $expr = "^([+]91[ ]|0)[0-9]{2,7}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'iq' :
                $expr = "^([+]964[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,9}$";
                break;
            case 'ir' :
                $expr = "^([+]97[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;

            case 'is' :
                $expr = "^([+]354[ ])?[0-9]{7,9}$";
                break;
            case 'it' :
                $expr = "^([+]39[ ])?[0-9]{1,3}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'jm' :
                $expr = "^([+]1[ ])?876[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'jo' :
                $expr = "^([+]962[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7,8}$";
                break;
            case 'jp' :
                $expr = "^([+]81[ ]|0)[0-9]{1,5}[ \.\-]?[0-9]{4,8}$";
                break;
            case 'ke' :
                $expr = "^([+]254[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'kg' :
                $expr = "^([+]996[ ]|0)[0-9]{3,4}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'kh' :
                $expr = "^([+]855[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'ki' :
                $expr = "^([+]686[ ])?[0-9]{5}$";
                break;
            case 'km' :
                $expr = "^([+]262[ ]|[+]269[ ])?[0-9]{6}$";
                break;
            case 'kn' :
                $expr = "^([+]1[ ])?869[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'kp' :
                $expr = "^([+]82[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'kr' :
                $expr = "^([+]850[ ]|0)?[0-9]{1,2}[ \.\-]?[0-9]{7}$";
                break;
            case 'ky' :
                $expr = "^([+]1[ ])?345[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'kw' :
                $expr = "^([+]965[ ])?[0-9]{7}$";
                break;
            case 'kz' :
                $expr = "^([+]7[ ]|8)[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'la' :
                $expr = "^([+]856[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'lb' :
                $expr = "^([+]961[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6}$";
                break;
            case 'lc' :
                $expr = "^([+]1[ ])?758[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'li' :
                $expr = "^([+]423[ ])?[0-9]{7}$";
                break;
            case 'lk' :
                $expr = "^([+]94[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'lr' :
                $expr = "^([+]231[ ])?[0-9]{6}$";
                break;
            case 'ls' :
                $expr = "^([+]266[ ])?[0-9]{8}$";
                break;
            case 'lt' :
                $expr = "^([+]370[ ]|0|8)[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'lu' :
                $expr = "^([+]352[ ])?[0-9]{5,11}$";
                break;
            case 'lv' :
                $expr = "^([+]371[ ]|8)?[0-9]{0,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ly' :
                $expr = "^([+]218[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ma' :
                $expr = "^([+]212[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'mc' :
                $expr = "^([+]377[ ])?[0-9]{8,9}$";
                break;
            case 'md' :
                $expr = "^([+]373[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'me' :
                $expr = "^([+]382[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'mg' :
                $expr = "^([+]261[ ])?([0-9]{2})?[0-9]{7}$";
                break;
            case 'mh' :
                $expr = "^([+]692[ ])?[1]{0,1}[ \.\-]?[0-9]{7}$";
                break;
            case 'mk' :
                $expr = "^([+]389[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ml' :
                $expr = "^([+]223[ ])?[0-9]{7}$";
                break;
            case 'mm' :
                $expr = "^([+]95[ ]|0)?[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'mn' :
                $expr = "^([+]976[ ]|01|02)[0-9]{1,4}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'mo' :
                $expr = "^([+]853[ ])?[0-9]{6,7}$";
                break;
            case 'mp' :
                $expr = "^([+]1[ ])?670[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'mq' :
                $expr = "^([+]596[ ])?[1-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'mr' :
                $expr = "^([+]222[ ])?[0-9]{7}$";
                break;
            case 'ms' :
                $expr = "^([+]1[ ])?664[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'mt' :
                $expr = "^([+]356[ ])?[0-9]{2}[ \.\-][0-9]{3}[ \.\-][0-9]{3}$";
                break;
            case 'mu' :
                $expr = "^([+]230[ ])?[0-9]{7}$";
                break;
            case 'mv' :
                $expr = "^([+]960[ ])?[0-9]{7}$";
                break;
            case 'mw' :
                $expr = "^([+]265[ ])?[0-9]{8}$";
                break;
            case 'mx' :
                $expr = "^([+]52[ ]|01|02)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'my' :
                $expr = "^([+]60[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'mz' :
                $expr = "^([+]258[ ])?[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'na' :
                $expr = "^([+]264[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{2,6}$";
                break;
            case 'nc' :
                $expr = "^([+]687[ ])?[0-9]{6}$";
                break;
            case 'ne' :
                $expr = "^([+]227[ ])?[0-9]{6}$";
                break;
            case 'ng' :
                $expr = "^([+]233[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ni' :
                $expr = "^([+]505[ ])?[0-9]{7}$";
                break;
            case 'nl' :
                $expr = "^([+]31[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'np' :
                $expr = "^([+]977[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'nr' :
                $expr = "^([+]674[ ])?[0-9]{7}$";
                break;
            case 'nu' :
                $expr = "^([+]683[ ])?[0-9]{4}$";
                break;
            case 'pa' :
                $expr = "^([+]507[ ])?[0-9]{7}$";
                break;
            case 'pf' :
                $expr = "^([+]689[ ])?[0-9]{2}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'pr' :
                $expr = "^([+]1[ ])?[787|939][ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'nf' :
            case 'pn' :
                $expr = "^([+]672[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{3,5}$";
                break;
            case 'no' :
                $expr = "^([+]47[ ])?[0-9]{8}$";
                break;
            case 'nz' :
                $expr = "^([+]64[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'om' :
                $expr = "^([+]968[ ])?[0-9]{6,8}$";
                break;
            case 'pe' :
                $expr = "^([+]51[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'pg' :
                $expr = "^([+]675[ ])?[0-9]{7}$";
                break;
            case 'ph' :
                $expr = "^([+]63[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'pk' :
                $expr = "^([+]92[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'pl' :
                $expr = "^([+]48[ ]|0)[0-9]{2}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{2}[ \.\-]?[0-9]{2}$";
                break;
            case 'pm' :
                $expr = "^([+]508[ ])?[0-9]{6}$";
                break;
            case 'ps' :
                $expr = "^([+]970[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'pt' :
                $expr = "^([+]351[ ])?[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'pw' :
                $expr = "^([+]680[ ])?[0-9]{7}$";
                break;
            case 'py' :
                $expr = "^([+]595[ ]|0)[0-9]{2,4}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'qa' :
                $expr = "^([+]974[ ])?[0-9]{6}$";
                break;
            case 'ro' :
                $expr = "^([+]40[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ru' :
                $expr = "^([+]7[ ]|8)[0-9]{3,5}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'rw' :
                $expr = "^([+]250[ ])?[0-9]{5,8}$";
                break;
            case 'sa' :
                $expr = "^([+]966[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'sc' :
                $expr = "^([+]248[ ])?[0-9]{6}$";
                break;
            case 'sd' :
                $expr = "^([+]249[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'sk' :
                $expr = "^([+]421[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{7,8}$";
                break;
            case 're' :
                $expr = "^([+]262[ ])?[0-9]{10}$";
                break;
            case 'sb' :
                $expr = "^([+]677[ ])?[0-9]{5}$";
                break;
            case 'se' :
                $expr = "^([+]46[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,8}$";
                break;
            case 'sg' :
                $expr = "^([+]65[ ])?[0-9]{7,8}$";
                break;
            case 'sh' :
                $expr = "^([+]290[ ])?[0-9]{4}$";
                break;
            case 'si' :
                $expr = "^([+]386[ ]|0)[0-9]{1}[ \.\-]?[0-9]{7}$";
                break;
            case 'sl' :
                $expr = "^([+]232[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6}$";
                break;
            case 'sm' :
                $expr = "^([+]378[ ])?[0-9]{10,12}$";
                break;
            case 'sn' :
                $expr = "^([+]221[ ])?[0-9]{7}$";
                break;
            case 'so' :
                $expr = "^([+]252[ ])?[0-9]{7}$";
                break;
            case 'sr' :
                $expr = "^([+]597[ ])?[0-9]{6}$";
                break;
            case 'st' :
                $expr = "^([+]239[ ])?[0-9]{6}$";
                break;
            case 'sv' :
                $expr = "^([+]503[ ])?[0-9]{7}$";
                break;
            case 'sy' :
                $expr = "^([+]963[ ]|0)[0-9]{2}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'sz' :
                $expr = "^([+]268[ ]|0)[0-9]{7}$";
                break;
            case 'tc' :
                $expr = "^([+]1[ ])?649[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'td' :
                $expr = "^([+]235[ ])?[0-9]{6}$";
                break;
            case 'th' :
                $expr = "^([+]66[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{6,7}$";
                break;
            case 'tg' :
                $expr = "^([+]228[ ])?[0-9]{7}$";
                break;
            case 'tj' :
                $expr = "^([+]998[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'tk' :
                $expr = "^([+]690[ ])?[0-9]{1}[ \.\-]?[0-9]{3}$";
                break;
            case 'tl' :
                $expr = "^([+]670[ ])?[0-9]{7}$";
                break;
            case 'tm' :
                $expr = "^([+]993[ ]|8)[0-9]{2,3}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'tn' :
                $expr = "^([+]216[ ]|0)[0-9]{8}$";
                break;
            case 'to' :
                $expr = "^([+]676[ ])?[0-9]{7}$";
                break;
            case 'tr' :
                $expr = "^([+]90[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;
            case 'tt' :
                $expr = "^([+]1[ ])?868[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'tv' :
                $expr = "^([+]688[ ])?[0-9]{5}$";
                break;
            case 'tw' :
                $expr = "^([+]886[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{6,8}$";
                break;
            case 'tz' :
                $expr = "^([+]255[ ]|0)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'ua' :
                $expr = "^([+]380[ ]|8)[0-9]{2,4}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'ug' :
                $expr = "^([+]256[ ]|0)[0-9]{2,3}[ \.\-]?[0-9]{4,7}$";
                break;
            case 'us' :
                $expr = "^([+]1[ ])?[0-9]{3}[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'uy' :
                $expr = "^([+]598[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{4,6}$";
                break;
            case 'uz' :
                $expr = "^([+]998[ ]|8)[0-9]{2}[ \.\-]?[0-9]{7}$";
                break;
            case 'vc' :
                $expr = "^([+]1[ ])?784[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 've' :
                $expr = "^([+]58[ ]|0)[0-9]{3}[ \.\-]?[0-9]{7}$";
                break;
            case 'vg' :
                $expr = "^([+]1[ ])?284[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'vi' :
                $expr = "^([+]1[ ])?340[ \.\-]?[0-9]{3}[ \.\-]?[0-9]{4}$";
                break;
            case 'vn' :
                $expr = "^([+]84[ ]|0)[0-9]{1,3}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'vu' :
                $expr = "^([+]678[ ])?[0-9]{5}$";
                break;
            case 'wf' :
                $expr = "^([+]681[ ])?[0-9]{6}$";
                break;
            case 'ws' :
                $expr = "^([+]685[ ])?[0-9]{6,7}$";
                break;
            case 'ye' :
                $expr = "^([+]967[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,7}$";
                break;
            case 'yt' :
                $expr = "^([+]262[ ]|[+]269[ ])?[0-9]{10}$";
                break;
            case 'za' :
                $expr = "^([+]27[ ]|0)[0-9]{2,5}[ \.\-]?[0-9]{3,7}$";
                break;
            case 'zm' :
                $expr = "^([+]260[ ]|0)[0-9]{1,2}[ \.\-]?[0-9]{5,6}$";
                break;
            case 'zw' :
                $expr = "^([+]263[ ]|0)[0-9]{1,4}[ \.\-]?[0-9]{3,8}$";
                break;
            default :
                $expr = "^([+][0-9]{2,3}[ ])?[0-9]{6,11}$";
                break;
        }
    } else {
        $expr = "^([+][0-9]{2,3}[ ])?[0-9]{6,11}$";
    }

    return $expr;
}

/**
 * Mise en majuscules de chaque première lettre d'un texte
 * Séparation par espaces, tiret, ou apostrophe
 *
 * @param $string
 *
 * @return string
 */
function ucname($string)
{
    $string = ucwords(strtolower($string));

    foreach ([' ', '-', '\''] as $delimiter) {
        if (strpos($string, $delimiter) !== false) {
            $string = implode($delimiter, array_map('ucfirst', explode($delimiter, $string)));
        }
    }
    return $string;
}
