<?php
/****************************************************************************************
 * SMI (Services Maintenance Interventions) est une gestion libre de maintenance et de SAV
 *
 * Version 1.0.4
 *
 * Copyright (C) 2006-2016  Sylvain FATOME
 * This program is free software; you can redistribute it and/or modify it under the terms
 * of the GNU General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program
 * (in the directory docs);
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 * Contact : galawa@free.fr
 *
 * Web : http://smi.no-ip.org
 ****************************************************************************************/

// Vérification des tentatives de hack
$pos = strpos($_SERVER['PHP_SELF'], 'inc.php');
if ($pos !== FALSE) {
    header('Location: ../index.php');
}

/*****************************************************/
/* Fonctions d'extension de la classe TCPDF          */
/*****************************************************/


/**
 * Etend la classe TCPDF pour créer des entête et pieds personnalisés
 *
 * Class PDF_SMI
 */
class PDF_SMI extends TCPDF
{
    public $tgen = 0;
    public $tact = '';

    public  $default_font = 'helvetica';
    public $font;
    public $font_by_lng = [
        'ja' => 'cid0jp',
        'bg' => 'freeserif',
        'ru' => 'freeserif',
        'uk' => 'freeserif',
        'mk' => 'freeserif',
        'el' => 'freeserif',
        'vn' => 'dejavusans',
        'pl' => 'dejavusans',
        'ar' => 'dejavusans',
        'fa' => 'dejavusans',
        'ur' => 'dejavusans',
        'az' => 'dejavusans',
        'ca' => 'dejavusans',
        'gl' => 'dejavusans',
        'hr' => 'dejavusans',
        'sr' => 'dejavusans',
        'si' => 'dejavusans',
        'cs' => 'dejavusans',
        'sk' => 'dejavusans',
        'ka' => 'dejavusans',
        'he' => 'dejavusans',
        'lo' => 'dejavusans',
        'lv' => 'dejavusans',
        'tr' => 'dejavusans',
        'ko' => 'cid0kr',
        'zh' => 'cid0cs',
        'tw' => 'cid0cs',
        'th' => 'freeserif'
    ];


    /**
     * Choix  de la plice en fonction du language
     *
     * @param $codelng
     */

    public function setFontLng($codelng)
    {
        $this->font = $default_font;

        if (array_key_exists($codelng, $this->font_by_lng)) {
            $this->font = $this->font_by_lng[$codelng];
        }

        $this->setHeaderFont([$this->font, '', PDF_FONT_SIZE_MAIN]);
        $this->setFooterFont([$this->font, '', PDF_FONT_SIZE_MAIN]);
        $this->SetFont($this->font);
    }

    public $theader = '';
    public $add_margin = 0;

    /**
     * Impression d'un filigrane
     *
     * @param $texte
     */

    public function filigrane($texte)
    {
        $marges = $this->getMargins();

        // On détermine le milieu

        $myX = ($this->getPageWidth() / 2) + $marges['left'];
        $myY = ($this->getPageHeight() / 2) + $marges['top'];

        // On passe en mode transparent
        $this->setAlpha(0.2);

        // Rotation de 45° et écriture
        $this->StartTransform();
        $this->Rotate(45, $myX, $myY);
        $this->SetFont('', 'B', 80);
        $this->Text(20, 150, $texte);
        $this->StopTransform();
        $this->setAlpha(1);
        $this->setPageMark();
    }


    /**
     * Type de génération
     */

    public function settgen()
    {
        $type = 0;
        if (isset($_GET['timp'])) {
            $type = (int)$_GET['timp'];
        }
        $this->tgen = $type;
        $type = 'cop';
        if (isset($_GET['tact'])) {
            $type = trim($_GET['tact']);
        }
        $this->tact = $type;
    }


    /**
     * Marge supplémentaire
     */

    public function set_add_margin()
    {
        // On détermine la largeur de la page et on réajuste les distances du cartouche de droite
        //$this->add_margin = 0;
        $page_width = $this->getPageWidth();
        if ($page_width > 210) {
            $this->add_margin = ($page_width - 210);
        }
    }


    /**
     * Type de header
     *
     * @param $type
     */
    public function settheader($type)
    {
        $this->theader = $type;
    }


    /**
     * Entête de page
     */
    public function Header()
    {
        /*** INITIALISATION ***/
        $url_image = ''; // URL vers l'image du logo
        $txt_ent_hg = ''; // Texte normal en haut à gauche
        $txt_ent_compl_hg = ''; // Texte complémentaire au logo en haut à gauche (italique)
        $txt_ent_it_hg = ''; // Texte en italique en haut à gauche
        $txt_titre_hd = ''; // Titre du document en haut à droite
        $txt_ent_hd = ''; // Texte normal en haut à droite
        $txt_ent_compl_hd = ''; // Texte complémentaire en haut à droite
        $txt_ent_compl1_it_hd = ''; // Texte complémentaire N°1 en haut à droite (italique)
        $txt_ent_compl2_it_hd = ''; // Texte complémentaire N°2 en haut à droite (italique)
        $txt_type_etat = ''; // Texte du type d'état
        $txt_cb = ''; // Texte code barre

        /*** TEXTES ENTETES HAUT GAUCHE ET HAUT DROITE ***/
        switch ($this->theader) {
            // Entête Contrats locations
            case 'col' :
                global
                $niv_util,
                $coloc_code,
                $cheminr_logos;

                // Récupération des données contrat
                $row = lit_enr_coloc($coloc_code, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    //Récupération des données agence
                    $row = lit_enr_age($coloc_codeage, TRUE);
                    if ($row) {
                        extract($row);

                        // Logo
                        $this->Image($cheminr_logos . '/log' . strtolower($age_code) . '.png', 10, 10, 0, 17); // Image à 10mm du bord gauche, 10mm du bord haut, hauteur maximum 17mm

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }

                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('CONTRAT LOCATION');

                    // Entête Dossier (Haut droite)
                    $txt_ent_hd = _('N°') . $coloc_code . "\n";
                    $txt_ent_hd .= "\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($coloc_datecrea);

                    // Texte complémentaire (Haut droite)
                    if (datetolocal($coloc_dateclos) <> '') // Affichage si contrat clot
                    {
                        $txt_ent_compl_hd = _('TERMINE');
                    }

                    // Code Barre
                    $txt_cb = $coloc_code;

                    // "Duplicata" si demande client
                    if ($niv_util == 1) {
                        $this->filigrane(_('DUPLICATA'));
                    }
                }
                break;

            // Entête contrats clients
            case 'cocl' :
                global
                $cocl_code,
                $datea,
                $cheminr_logos;

                // Récupération des données contrat
                $row = lit_enr_cocl($cocl_code, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    //Récupération des données agence
                    $row = lit_enr_age($cocl_codeage, TRUE);

                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('CONTRAT');

                    // Entête Dossier (Haut droite)
                    $txt_ent_hd = _('N°') . $cocl_code . "\n";
                    $txt_ent_hd .= "\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($cocl_datecrea);

                    // Texte complémentaire (Haut droite)
                    if ((datetolocal($cocl_datefin) <> '') OR comp_date($cocl_datef, $datea)) // Affichage si contrat clot
                    {
                        $txt_ent_compl_hd = _('TERMINE');
                    }

                    // Code Barre
                    $txt_cb = $cocl_code;

                    // "Duplicata" si signé (pas de réimpression d'original pour le client !)
                    if ((datetolocal($cocl_datesig) <> '') OR ($this->tgen == 1)) {
                        $this->filigrane(_('DUPLICATA'));
                    }
                }
                break;

            // Entête synthèse contrat clients
            case 'cocls' :
                global
                $cocl_code,
                $datea,
                $cheminr_logos;

                // Récupération des données contrat
                $row = lit_enr_cocl($cocl_code, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    // Récupération des données agence
                    $row = lit_enr_age($cocl_codeage, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('SYNTHESE DE CONTRAT');

                    // Entête Dossier (Haut droite)
                    $txt_ent_hd = _('N°') . $cocl_code . "\n";
                    $txt_ent_hd .= "\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($cocl_datecrea);

                    // Texte complémentaire (Haut droite)
                    if ((datetolocal($cocl_datefin) <> '') OR comp_date($cocl_datef, $datea)) // Affichage si contrat clot
                    {
                        $txt_ent_compl_hd = _('TERMINE');
                    }

                    // Code Barre
                    $txt_cb = $cocl_code;

                    // "Duplicata" si signé (pas de réimpression d'original pour le client !)
                    if ((datetolocal($cocl_datesig) <> '') OR ($this->tgen == 1)) {
                        $this->filigrane(_('DUPLICATA'));
                    }
                }
                break;

            // Entête synthèses contrats clients
            case 'coclsm' :
                global
                $tco,
                $cli_prop,
                $cheminr_logos;

                // Logo
                // Image à 10mm du bord gauche, 10mm du bord haut, hauteur maximum 17mm
                if (($cli_prop <> '') AND ($cli_prop <> NULL)) {
                    //Récupération des données agence
                    $row = lit_enr_age($cli_prop, FALSE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, FALSE) . ' ' . Retourneville_Id($age_ville, FALSE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;

                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                } else {
                    $row = lit_enr_cdg(FALSE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/logcge.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $cge_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $cge_adr1 . "\n";
                        if ($cge_adr2 <> '') {
                            $txt_ent_hg .= $cge_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($cge_ville, FALSE) . ' ' . Retourneville_Id($cge_ville, FALSE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $cge_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $cge_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $cge_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $cge_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $cge_email . "\n";
                        $txt_ent_it_hg .= "\n\n";
                    }
                }

                // Entête synthèse de Contrat
                switch ($tco) {
                    case 'o' :
                        $txt_titre_hd = _('SYNTHESE DES CONTRATS OUVERTS');
                        break;
                    case 'c' :
                        $txt_titre_hd = _('SYNTHESE DES CONTRATS CLOTS');
                        break;
                    default :
                        $txt_titre_hd = _('SYNTHESE DES CONTRATS');
                        break;
                }
                break;

            // Entête dossiers
            case 'dos' :
                global
                $cheminr_logos,
                $dos_code;

                //Récupération des données dossier
                $row = lit_enr_dos($dos_code, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    //Récupération des données agence
                    $row = lit_enr_age($dos_codeage, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('SYNTHESE DOSSIER');

                    // Entête Dossier (Haut droite)
                    $txt_ent_hd = _('N°') . $dos_code . "\n";
                    $txt_ent_hd .= "\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($dos_datedde);

                    // Texte complémentaire (Haut droite)
                    if (datetolocal($dos_datefin) <> '') // Affichage si intervention close
                    {
                        $txt_ent_compl_hd = _('CLOS');
                    }

                    // Code Barre
                    $txt_cb = $dos_code;
                }
                break;

            // Entête Départs/Retours de locations
            case 'dr' :
                global
                $pdtloc_des,
                $pdtloc_ns,
                $pdtl_dateret,
                $coloc_codeage,
                $cheminr_logos;

                //Récupération des données agence
                $row = lit_enr_age($coloc_codeage, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                    // Texte complémentaire au logo
                    $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                    // Texte coordonnées (texte normal)
                    $txt_ent_hg = $age_adr1 . "\n";
                    if ($age_adr2 <> '') {
                        $txt_ent_hg .= $age_adr2 . "\n";
                    }
                    $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                    $txt_ent_hg .= _('Tel') . ' : ';
                    $txt_ent_hg .= $age_telf;
                    if ($age_txttelf <> '') {
                        $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                    } else {
                        $txt_ent_hg .= "\n";
                    }
                    $txt_ent_hg .= _('Fax') . ' : ';
                    $txt_ent_hg .= $age_fax;
                    if ($age_txtfax <> '') {
                        $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                    } else {
                        $txt_ent_hg .= "\n";
                    }

                    // Textes complémentaires (italique)
                    if ($age_web <> '') {
                        $txt_ent_it_hg = _('Site Web') . ' : ';
                        $txt_ent_it_hg .= $age_web . ' / ';
                    }
                    $txt_ent_it_hg .= _('Email') . ' : ';
                    $txt_ent_it_hg .= $age_email . "\n";
                    $txt_ent_it_hg .= _('Horaires') . ' : ';
                    $txt_ent_it_hg .= $age_heures . "\n";
                    $txt_ent_it_hg .= formatetxt($age_txtent);
                }

                // Titre (Haut droite)
                $txt_titre_hd = _('DEPART/RETOUR LOCATION');

                // Entête Dossier (Haut droite)
                $txt_ent_hd = $pdtloc_des . "\n";

                // Texte complémentaire (Haut droite)
                if (datetolocal($pdtl_dateret) <> '') // Affichage si produit rendu
                {
                    $txt_ent_compl_hd = _('PRODUIT RENDU');
                }

                // Code Barre
                $txt_cb = $pdtloc_ns;
                break;

            // Entête interventions
            case 'int' :
                global
                $niv_util,
                $int_code,
                $cheminr_logos,
                $te,
                $_SESSION;

                $row = lit_enr_int($int_code, TRUE);
                if (is_array($row)) {
                    $row = encode_str($row);
                    extract($row);

                    // Si pas de donneur d'ordre, entête "classique"
                    // Ou si pour sous-traitant
                    if (($int_codedo == '') OR ($niv_util = 11) OR ($niv_util = 10)) {

                        // Logo Agence
                        if ($int_codeage <> '') {
                            //Récupération des données agence
                            $row = lit_enr_age($int_codeage, TRUE);
                            if ($row) {
                                $row = encode_str($row);
                                extract($row);

                                // Logo
                                $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                                // Texte complémentaire au logo
                                $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                                // Texte coordonnées (texte normal)
                                $txt_ent_hg = $age_adr1 . "\n";

                                if ($age_adr2 <> '') {
                                    $txt_ent_hg .= $age_adr2 . "\n";
                                }

                                $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                                $txt_ent_hg .= _('Tel') . ' : ';
                                $txt_ent_hg .= $age_telf;
                                if ($age_txttelf <> '') {
                                    $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }
                                $txt_ent_hg .= _('Fax') . ' : ';
                                $txt_ent_hg .= $age_fax;
                                if ($age_txtfax <> '') {
                                    $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }

                                // Textes complémentaires (italique)
                                if ($age_web <> '') {
                                    $txt_ent_it_hg = _('Site Web') . ' : ';
                                    $txt_ent_it_hg .= $age_web . ' / ';
                                }

                                $txt_ent_it_hg .= _('Email') . ' : ';
                                $txt_ent_it_hg .= $age_email . "\n";
                                $txt_ent_it_hg .= _('Horaires') . ' : ';
                                $txt_ent_it_hg .= $age_heures . "\n";
                                $txt_ent_it_hg .= formatetxt($age_txtent);
                            }
                        } else {
                            $row = lit_enr_cdg();
                            if ($row) {
                                $row = encode_str($row);
                                extract($row);

                                // Logo
                                $url_image = $cheminr_logos . '/logcge.png';

                                // Texte complémentaire au logo
                                $txt_ent_compl_hg = _('SIRET') . ' : ' . $cge_rcs;

                                // Texte coordonnées (texte normal)
                                $txt_ent_hg = $cge_adr1 . "\n";
                                if ($cge_adr2 <> '') {
                                    $txt_ent_hg .= $cge_adr2 . "\n";
                                }
                                $txt_ent_hg .= Retournecp_Id($cge_ville, TRUE) . ' ' . Retourneville_Id($cge_ville, TRUE) . "\n";
                                $txt_ent_hg .= _('Tel') . ' : ';
                                $txt_ent_hg .= $cge_telf;
                                if ($age_txttelf <> '') {
                                    $txt_ent_hg .= ' (' . $cge_txttelf . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }
                                $txt_ent_hg .= _('Fax') . ' : ';
                                $txt_ent_hg .= $cge_fax;
                                if ($cge_txtfax <> '') {
                                    $txt_ent_hg .= ' (' . $cge_txtfax . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }

                                // Textes complémentaires (italique)
                                $txt_ent_it_hg .= _('Email') . ' : ';
                                $txt_ent_it_hg .= $cge_email . "\n";
                                $txt_ent_it_hg .= "\n\n";
                            }
                        }
                    }

                    if ($int_codedo <> '') {
                        //Récupération des données donneur d'ordres
                        $row = lit_enr_do($int_codedo, TRUE);
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);

                            // Logo
                            $url_image = $cheminr_logos . '/log' . strtolower($do_code) . '.png';

                            // Texte complémentaire au logo
                            $txt_ent_compl_hg = _('SIRET') . ' : ' . $do_rcs;

                            // Texte coordonnées (texte normal)
                            $txt_ent_hg = $do_adr1 . "\n";
                            if ($age_adr2 <> '') {
                                $txt_ent_hg .= $do_adr2 . "\n";
                            }
                            $txt_ent_hg .= Retournecp_Id($do_ville, TRUE) . ' ' . Retourneville_Id($do_ville, TRUE) . "\n";
                            $txt_ent_hg .= _('Tel') . ' : ';
                            $txt_ent_hg .= $do_telf;
                            if ($do_txttelf <> '') {
                                $txt_ent_hg .= ' (' . $do_txttelf . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }
                            $txt_ent_hg .= _('Fax') . ' : ';
                            $txt_ent_hg .= $do_fax;
                            if ($do_txtfax <> '') {
                                $txt_ent_hg .= ' (' . $do_txtfax . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }

                            // Textes complémentaires (italique)
                            if ($do_web <> '') {
                                $txt_ent_it_hg = _('Site Web') . ' : ';
                                $txt_ent_it_hg .= $do_web . ' / ';
                            }
                            $txt_ent_it_hg .= _('Email') . ' : ';
                            $txt_ent_it_hg .= $do_email . "\n";
                            $txt_ent_it_hg .= _('Horaires') . ' : ';
                            $txt_ent_it_hg .= $do_heures . "\n";
                            $txt_ent_it_hg .= formatetxt($do_txtent);
                        }
                    }

                    // Titre (Haut droite)
                    if ($int_codestatut == 'ACC') // On attend une commande client
                    {
                        $txt_titre_hd = _('ATTENTE CONFIRMATION');
                    } else {
                        if ($int_dateprevf == '') {
                            $txt_titre_hd = _('FICHE INTERVENTION');
                        } else {
                            $txt_titre_hd = _('RAPPORT INTERVENTION');
                        }
                    }

                    // Entête Dossier (Haut droite)
                    if ($int_code <> '') {
                        $txt_ent_hd = _('N°') . $int_code . "\n";
                        $txt_ent_hd .= "\n\n\n";
                        $txt_ent_hd .= _('Date création') . ' : ';
                        $txt_ent_hd .= datetolocal($int_datedde);

                        if (($niv_util == 5) OR ($niv_util == 9) OR ($niv_util == 4) OR ($niv_util == 3) OR ($niv_util == 1)) {
                            // Code saisie manuelle
                            if (trim($int_codeman) <> '') {
                                $txt_ent_compl1_it_hd .= _('S.I.') . ' : ' . $int_codeman;
                            }

                            // Code ordre client
                            if (trim($int_codeocli) <> '') {
                                $txt_ent_compl2_it_hd .= _('O.C.') . ' : ' . $int_codeocli;
                            }
                        }
                    } else {
                        $txt_ent_hd = _('SAISIE MANUELLE') . "\n";
                        $txt_ent_hd .= _('A REGULARISER') . "\n\n";
                        $txt_ent_hd .= _('Date création') . ' : ____/____/________';
                    }

                    // Texte complémentaire (Haut droite)
                    if (datetolocal($int_datefin) <> '') // Affichage si intervention close
                    {
                        $txt_ent_compl_hd = _('TERMINEE');
                    }

                    // Code Barre
                    $txt_cb = $int_code;

                    // Type d'état
                    if ($int_codestatut == 'ACC') // On attend une commande client pour intervention sur site
                    {
                        $txt_type_etat = _("Demande d'intervention");
                    } else // Le client a déjà donné son accord
                    {
                        if (datetolocal($int_dateprev) == '') {
                            $txt_type_etat = _('Fiche de travail');
                        } else {
                            $txt_type_etat = _('Rapport de travail');
                        }
                    }

                    // Duplicata pour les clients (pas de réimpression d'original pour le client !)
                    $duplicata = FALSE;
                    switch ($niv_util) {
                        case 1 :
                            $duplicata = TRUE;
                            break;
                        default :
                            if ($te == 'cli') {
                                $duplicata = TRUE;
                            }
                            break;
                    }


                    if ($this->tgen == 1) {
                        $duplicata = TRUE;
                    }

                    if ($duplicata == TRUE) {
                        $this->filigrane(_('DUPLICATA'));
                    }
                } else { // Bon vierge
                    switch ($niv_util) {
                        case 3 :
                        case 4 :
                            //Récupération des données agence
                            $row = lit_enr_age($_SESSION['code_age'], TRUE);
                            if ($row) {
                                $row = encode_str($row);
                                extract($row);

                                // Logo
                                $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                                // Texte complémentaire au logo
                                $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                                // Texte coordonnées (texte normal)
                                $txt_ent_hg = $age_adr1 . "\n";

                                if ($age_adr2 <> '') {
                                    $txt_ent_hg .= $age_adr2 . "\n";
                                }
                                $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                                $txt_ent_hg .= _('Tel') . ' : ';
                                $txt_ent_hg .= $age_telf;
                                if ($age_txttelf <> '') {
                                    $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }
                                $txt_ent_hg .= _('Fax') . ' : ';
                                $txt_ent_hg .= $age_fax;
                                if ($age_txtfax <> '') {
                                    $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }

                                // Textes complémentaires (italique)
                                if ($age_web <> '') {
                                    $txt_ent_it_hg = _('Site Web') . ' : ';
                                    $txt_ent_it_hg .= $age_web . ' / ';
                                }
                                $txt_ent_it_hg .= _('Email') . ' : ';
                                $txt_ent_it_hg .= $age_email . "\n";
                                $txt_ent_it_hg .= _('Horaires') . ' : ';
                                $txt_ent_it_hg .= $age_heures . "\n";
                                $txt_ent_it_hg .= formatetxt($age_txtent);
                            }
                            break;

                        case 5 :
                        case 9 :
                            $row = lit_enr_cdg();
                            if ($row) {
                                $row = encode_str($row);
                                extract($row);

                                // Logo
                                $url_image = $cheminr_logos . '/logcge.png';

                                // Texte complémentaire au logo
                                $txt_ent_compl_hg = _('SIRET') . ' : ' . $cge_rcs;

                                // Texte coordonnées (texte normal)
                                $txt_ent_hg = $cge_adr1 . "\n";
                                if ($cge_adr2 <> '') {
                                    $txt_ent_hg .= $cge_adr2 . "\n";
                                }
                                $txt_ent_hg .= Retournecp_Id($cge_ville, TRUE) . ' ' . Retourneville_Id($cge_ville, TRUE) . "\n";
                                $txt_ent_hg .= _('Tel') . ' : ';
                                $txt_ent_hg .= $cge_telf;
                                if ($age_txttelf <> '') {
                                    $txt_ent_hg .= ' (' . $cge_txttelf . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }
                                $txt_ent_hg .= _('Fax') . ' : ';
                                $txt_ent_hg .= $cge_fax;
                                if ($age_txtfax <> '') {
                                    $txt_ent_hg .= ' (' . $cge_txtfax . ")\n";
                                } else {
                                    $txt_ent_hg .= "\n";
                                }

                                // Textes complémentaires (italique)
                                $txt_ent_it_hg .= _('Email') . ' : ';
                                $txt_ent_it_hg .= $cge_email . "\n";
                                $txt_ent_it_hg .= "\n\n";
                            }
                            break;
                    }
                }
                break;

            // Entête ordres de travail
            case 'ot' :
                global
                $niv_util,
                $ot_code,
                $cheminr_logos;

                $row = lit_enr_ot($ot_code);
                if (is_array($row)) {
                    $row = encode_str($row);
                    extract($row);

                    if ($ot_codeint <> '--AR--') {
                        $row = lit_enr_int($ot_codeint);
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);

                            // Coordonnées agence concernée
                            $row = lit_enr_age($int_codeage, TRUE);
                            $row = encode_str($row);
                            extract($row);
                        }
                    } else {
                        $row = lit_enr_cli($ot_codecli, TRUE);
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);
                            if (trim($cli_prop) <> '') {
                                // Coordonnées agence concernée
                                $row = lit_enr_age($cli_prop, TRUE);
                                if ($row) {
                                    $row = encode_str($row);
                                    extract($row);
                                }
                            }
                        }
                    }

                    // Si agence rattachée, on part sur la base de l'agence
                    if (trim($age_code) <> '') {
                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    } else // Sinon, on part sur la base du sous-traitant
                    {
                        // Coordonnées compte sous-traitant
                        if ($ot_codest <> '') {
                            $row = lit_enr_st($ot_codest);
                            $row = encode_str($row);
                            extract($row);

                            // Logo
                            $url_image = $cheminr_logos . '/log' . strtolower($st_code) . '.png';

                            // Texte complémentaire au logo
                            $txt_ent_compl_hg = _('SIRET') . ' : ' . $st_rcs;

                            // Texte coordonnées (texte normal)
                            $txt_ent_hg = $st_adr1 . "\n";
                            if ($st_adr2 <> '') {
                                $txt_ent_hg .= $st_adr2 . "\n";
                            }
                            $txt_ent_hg .= Retournecp_Id($st_ville, TRUE) . ' ' . Retourneville_Id($st_ville, TRUE) . "\n";
                            $txt_ent_hg .= _('Tel') . ' : ';
                            $txt_ent_hg .= $st_telf;
                            if ($st_txttelf <> '') {
                                $txt_ent_hg .= ' (' . $st_txttelf . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }
                            $txt_ent_hg .= _('Fax') . ' : ';
                            $txt_ent_hg .= $st_fax;
                            if ($st_txtfax <> '') {
                                $txt_ent_hg .= ' (' . $st_txtfax . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }

                            // Textes complémentaires (italique)
                            if ($st_web <> '') {
                                $txt_ent_it_hg = _('Site Web') . ' : ';
                                $txt_ent_it_hg .= $st_web . ' / ';
                            }
                            $txt_ent_it_hg .= _('Email') . ' : ';
                            $txt_ent_it_hg .= $st_email . "\n";
                            $txt_ent_it_hg .= _('Horaires') . ' : ';
                            $txt_ent_it_hg .= $st_heures . "\n";
                            $txt_ent_it_hg .= formatetxt($st_txtent);
                        }
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('BON DE TRAVAIL');

                    // Entête ordre (Haut droite)
                    $txt_ent_hd = _('N°') . $ot_code . "\n";
                    $txt_ent_hd .= "\n\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($ot_datedde);

                    // Code Barre
                    $txt_cb = $ot_code;

                    // Texte complémentaire (Haut droite)
                    if (datetolocal($ot_datefin) <> '') // Affichage si ordre clôt
                    {
                        $txt_ent_compl_hd = _('TERMINE');
                    }

                    // Type d'état
                    if (datetolocal($ot_dateprev) == '') {
                        $txt_type_etat = _('Fiche de travail');
                    } else {
                        $txt_type_etat = _('Rapport de travail');
                    }

                    // Duplicata pour les donneurs d'ordres
                    if (($niv_util == 11) OR ($niv_util == 10)) {
                        $this->filigrane(_('DUPLICATA'));
                    }
                }
                break;

            // Relevés de parc
            case 'rel' :
                global
                $rel_code,
                $cheminr_logos;

                //Récupération des données dossier
                $row = lit_enr_rel($rel_code, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    //Récupération des données agence
                    $row = lit_enr_age($rel_codeage, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= $cp_age . ' ' . $ville_age . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    $txt_titre_hd = _('RELEVE DE PARC');

                    // Entête ordre (Haut droite)
                    $txt_ent_hd = _('N°') . $rel_code . "\n";
                    $txt_ent_hd .= "\n\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($rel_datecrea);

                    // Code Barre
                    $txt_cb = $rel_code;
                }
                break;

            // Relevés de parc vierges
            case 'relv' :
                global
                $agence,
                $tfr,
                $cheminr_logos;

                //Récupération des données agence
                $row = lit_enr_age($agence, TRUE);
                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    // Logo
                    $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                    // Texte complémentaire au logo
                    $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                    // Texte coordonnées (texte normal)
                    $txt_ent_hg = $age_adr1 . "\n";
                    if ($age_adr2 <> '') {
                        $txt_ent_hg .= $age_adr2 . "\n";
                    }
                    $txt_ent_hg .= $cp_age . ' ' . $ville_age . "\n";
                    $txt_ent_hg .= _('Tel') . ' : ';
                    $txt_ent_hg .= $age_telf;
                    if ($age_txttelf <> '') {
                        $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                    } else {
                        $txt_ent_hg .= "\n";
                    }
                    $txt_ent_hg .= _('Fax') . ' : ';
                    $txt_ent_hg .= $age_fax;
                    if ($age_txtfax <> '') {
                        $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                    } else {
                        $txt_ent_hg .= "\n";
                    }

                    // Textes complémentaires (italique)
                    if ($age_web <> '') {
                        $txt_ent_it_hg = _('Site Web') . ' : ';
                        $txt_ent_it_hg .= $age_web . ' / ';
                    }
                    $txt_ent_it_hg .= _('Email') . ' : ';
                    $txt_ent_it_hg .= $age_email . "\n";
                    $txt_ent_it_hg .= _('Horaires') . ' : ';
                    $txt_ent_it_hg .= $age_heures . "\n";
                    $txt_ent_it_hg .= formatetxt($age_txtent);
                }

                // Titre (Haut droite)
                if ($tfr == 1) {
                    $txt_titre_hd = _('RELEVE LICENCE VIERGE');
                } else {
                    $txt_titre_hd = _('RELEVE MATERIEL VIERGE');
                }

                // Entête ordre (Haut droite)
                $txt_ent_hd = "\n" . _('Date saisie') . ' : __/__/____';
                $txt_ent_hd .= "\n" . _('Par') . ' : ' . str_repeat('_', 40);
                break;

            // Demandes de retour
            case 'retd' :
            case 'rete' :
                global
                $rete_id,
                $retd_id,
                $cheminr_logos;

                $codeage = '';

                if ($this->theader == 'retd') {
                    //Récupération des données dossier
                    $row = lit_enr_retd_id($retd_id, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);
                        // Récupération des informations fiche produit à retourner
                        $row = lit_enr_retp($retd_coderetp, TRUE);
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);
                            $codeage = $retp_codeage;
                        }
                    }
                } else {
                    //Récupération des données dossier
                    $row = lit_enr_rete_id($rete_id, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);
                        $codeage = $rete_codeage;
                    }
                }

                if ($codeage <> '') {
                    //Récupération des données agence
                    $row = lit_enr_age($codeage, TRUE);
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= $cp_age . ' ' . $ville_age . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }
                }

                // Titre (Haut droite)
                if ($this->theader == 'retd') {
                    $txt_titre_hd = _('DEMANDE DE RETOUR');
                } else {
                    $txt_titre_hd = _('RENVOI DE PRODUITS');

                    // Entête ordre (Haut droite)
                    $txt_ent_hd = _('N°') . $rete_code . "\n";
                }
                $txt_ent_hd .= "\n\n\n";
                $txt_ent_hd .= _('Date') . ' : ';
                if ($this->theader == 'retd') {
                    $txt_ent_hd .= datetolocal($retd_datedde);
                } else {
                    $txt_ent_hd .= datetolocal($rete_dateenv);
                }

                // Code Barre
                if ($this->theader == 'rete') {
                    $txt_cb = $rete_code;
                }

                break;

            // Fiche Relevé matériel ou licence
            case 'rpdt' :
            case 'rlic' :
                global
                $rlic_code,
                $rpdt_code,
                $cheminr_logos;

                //Récupération des données dossier
                if ($this->theader == 'rpdt') {
                    $row = lit_enr_rpdt($rpdt_code, TRUE);
                } else {
                    $row = lit_enr_rlic($rlic_code, TRUE);
                }

                if ($row) {
                    $row = encode_str($row);
                    extract($row);

                    //Récupération des données agence
                    if ($this->theader == 'rpdt') {
                        $row = lit_enr_age($rpdt_codeage, TRUE);
                    } else {
                        $row = lit_enr_age($rlic_codeage, TRUE);
                    }
                    if ($row) {
                        $row = encode_str($row);
                        extract($row);

                        // Logo
                        $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                        // Texte complémentaire au logo
                        $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                        // Texte coordonnées (texte normal)
                        $txt_ent_hg = $age_adr1 . "\n";
                        if ($age_adr2 <> '') {
                            $txt_ent_hg .= $age_adr2 . "\n";
                        }
                        $txt_ent_hg .= $cp_age . ' ' . $ville_age . "\n";
                        $txt_ent_hg .= _('Tel') . ' : ';
                        $txt_ent_hg .= $age_telf;
                        if ($age_txttelf <> '') {
                            $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }
                        $txt_ent_hg .= _('Fax') . ' : ';
                        $txt_ent_hg .= $age_fax;
                        if ($age_txtfax <> '') {
                            $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                        } else {
                            $txt_ent_hg .= "\n";
                        }

                        // Textes complémentaires (italique)
                        if ($age_web <> '') {
                            $txt_ent_it_hg = _('Site Web') . ' : ';
                            $txt_ent_it_hg .= $age_web . ' / ';
                        }
                        $txt_ent_it_hg .= _('Email') . ' : ';
                        $txt_ent_it_hg .= $age_email . "\n";
                        $txt_ent_it_hg .= _('Horaires') . ' : ';
                        $txt_ent_it_hg .= $age_heures . "\n";
                        $txt_ent_it_hg .= formatetxt($age_txtent);
                    }

                    // Titre (Haut droite)
                    if ($this->theader == 'rpdt') {
                        $txt_titre_hd = _('RELEVE DE MATERIEL');
                    } else {
                        $txt_titre_hd = _('RELEVE DE LICENCE');
                    }

                    // Entête Dossier (Haut droite)
                    if ($this->theader == 'rpdt') {
                        $txt_ent_hd = _('N°') . $rpdt_code . "\n";
                    } else {
                        $txt_ent_hd = _('N°') . $rlic_code . "\n";
                    }
                    $txt_ent_hd .= "\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    if ($this->theader == 'rpdt') {
                        $txt_ent_hd .= datetolocal($rpdt_datecrea);
                    } else {
                        $txt_ent_hd .= datetolocal($rlic_datecrea);
                    }

                    // Code Barre
                    $txt_cb = $rlic_code;
                    if ($this->theader == 'rpdt') {
                        $txt_cb = $rpdt_code;
                    }
                }
                break;
            // Coupons
            case 'coupc' :
            case 'coupma' :
                global
                $niv_util,
                $int_code,
                $cheminr_logos,
                $_SESSION;

                $row = lit_enr_int($int_code, TRUE);
                if (is_array($row)) {
                    $row = encode_str($row);
                    extract($row);

                    // Logo Agence
                    if ($int_codeage <> '') {
                        //Récupération des données agence
                        $row = lit_enr_age($int_codeage, TRUE);
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);

                            // Logo
                            $url_image = $cheminr_logos . '/log' . strtolower($age_code) . '.png';

                            // Texte complémentaire au logo
                            $txt_ent_compl_hg = _('SIRET') . ' : ' . $age_rcs;

                            // Texte coordonnées (texte normal)
                            $txt_ent_hg = $age_adr1 . "\n";

                            if ($age_adr2 <> '') {
                                $txt_ent_hg .= $age_adr2 . "\n";
                            }

                            $txt_ent_hg .= Retournecp_Id($age_ville, TRUE) . ' ' . Retourneville_Id($age_ville, TRUE) . "\n";
                            $txt_ent_hg .= _('Tel') . ' : ';
                            $txt_ent_hg .= $age_telf;
                            if ($age_txttelf <> '') {
                                $txt_ent_hg .= ' (' . $age_txttelf . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }
                            $txt_ent_hg .= _('Fax') . ' : ';
                            $txt_ent_hg .= $age_fax;
                            if ($age_txtfax <> '') {
                                $txt_ent_hg .= ' (' . $age_txtfax . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }

                            // Textes complémentaires (italique)
                            if ($age_web <> '') {
                                $txt_ent_it_hg = _('Site Web') . ' : ';
                                $txt_ent_it_hg .= $age_web . ' / ';
                            }

                            $txt_ent_it_hg .= _('Email') . ' : ';
                            $txt_ent_it_hg .= $age_email . "\n";
                            $txt_ent_it_hg .= _('Horaires') . ' : ';
                            $txt_ent_it_hg .= $age_heures . "\n";
                            $txt_ent_it_hg .= formatetxt($age_txtent);
                        }
                    } else {
                        $row = lit_enr_cdg();
                        if ($row) {
                            $row = encode_str($row);
                            extract($row);

                            // Logo
                            $url_image = $cheminr_logos . '/logcge.png';

                            // Texte complémentaire au logo
                            $txt_ent_compl_hg = _('SIRET') . ' : ' . $cge_rcs;

                            // Texte coordonnées (texte normal)
                            $txt_ent_hg = $cge_adr1 . "\n";
                            if ($cge_adr2 <> '') {
                                $txt_ent_hg .= $cge_adr2 . "\n";
                            }
                            $txt_ent_hg .= Retournecp_Id($cge_ville, TRUE) . ' ' . Retourneville_Id($cge_ville, TRUE) . "\n";
                            $txt_ent_hg .= _('Tel') . ' : ';
                            $txt_ent_hg .= $cge_telf;
                            if ($age_txttelf <> '') {
                                $txt_ent_hg .= ' (' . $cge_txttelf . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }
                            $txt_ent_hg .= _('Fax') . ' : ';
                            $txt_ent_hg .= $cge_fax;
                            if ($cge_txtfax <> '') {
                                $txt_ent_hg .= ' (' . $cge_txtfax . ")\n";
                            } else {
                                $txt_ent_hg .= "\n";
                            }

                            // Textes complémentaires (italique)
                            $txt_ent_it_hg .= _('Email') . ' : ';
                            $txt_ent_it_hg .= $cge_email . "\n";
                            $txt_ent_it_hg .= "\n\n";
                        }
                    }
                }

                // Titre (Haut droite)
                if ($this->theader == 'coupc') { // Coupon client
                    $txt_titre_hd = _('COUPON CLIENT');
                } else {
                    $txt_titre_hd = _('COUPON MATERIEL');
                }

                // Entête Coupon (Haut droite)
                if ($int_code <> '') {
                    $txt_ent_hd = _('N°') . $int_code . "\n";
                    $txt_ent_hd .= "\n\n\n";
                    $txt_ent_hd .= _('Date création') . ' : ';
                    $txt_ent_hd .= datetolocal($int_datedde);
                }

                // Code Barre
                $txt_cb = $int_code;

                $this->SetTopMargin(0.5);
                break;
            default :
                $this->SetTopMargin(0.5);
                break;
        }

        /*** IMPRESSION DES ENTETES ***/
        if ($txt_ent_hg <> '') {
            // On sauve la couleur en cours et on se met en noir
            $ex_couleurtxt = $this->TextColor;
            $this->SetTextColor(0);

            // On sauve la marge en cours et on se met à 10
            $ex_lMargin = $this->lMargin;
            $this->SetLeftMargin(10);
            $pv_ent_hg = 27; // Valeur de départ (mm) du pointeur pour l'affichage agence par rapport au bord haut de la feuille

            // Cette valeur comprend la hauteur du logo (20 mm)
            $pv_ent_hd = 10; // Valeur de départ (mm) du pointeur pour l'affichage de l'entête détail (haut droite) par rapport au bord haut de la feuille


            /*** AFFICHAGE LOGO + TEXTE HAUT GAUCHE ***/

            // Logo
            if ($url_image <> '') {
                $this->Image($url_image, 10, 10, 0, 17);
            } // Image à 10mm du bord gauche, 10mm du bord haut, hauteur maximum 17mm

            $this->SetY($pv_ent_hg);

            // Texte complémentaire au logo
            if ($txt_ent_compl_hg <> '') {
                $this->SetFont('', 'I', 6);
                $this->Cell(95, 3, $txt_ent_compl_hg, 0, 0, 'L');
            }

            // Texte coordonnées
            $pv_ent_hg += 3;
            $this->SetY($pv_ent_hg);
            $this->SetFont('', '', 8);
            $this->MultiCell(95, 3, $txt_ent_hg, 0, 'L');

            // Texte complémentaire
            if ($txt_ent_it_hg <> '') {
                $this->SetFont('', 'I', 6); // Pas besoin de SetY car le MultiCell renvoie juste en dessous
                $this->MultiCell(95, 3, $txt_ent_it_hg, 0, 'L');
            }
            $pv_ent_hg = $this->GetY(); // Récupération de la position du pointeur

            /*** AFFICHAGE TEXTE HAUT DROITE ***/

            // Titre
            if ($txt_titre_hd <> '') {
                $this->SetY($pv_ent_hd);
                $this->Cell(95 + $this->add_margin);
                $this->SetFont('', 'BU', 14);
                $this->Cell(95, 10, $txt_titre_hd, 0, 1, 'C');
            }

            // Entête
            if ($txt_ent_hd <> '') {
                $pv_ent_hd += 10;
                $this->SetY($pv_ent_hd);
                $this->Cell(95 + $this->add_margin);
                $this->SetFont('', '', 10);
                $this->MultiCell(95, 5, $txt_ent_hd, 0, 'C');
            }

            // Texte complémentaire N°1
            if ($txt_ent_compl1_it_hd <> '') {
                $this->SetY($pv_ent_hd + 10);
                $this->Cell(95 + $this->add_margin);
                $this->SetFont('', 'I', 7);
                $this->MultiCell(95, 5, $txt_ent_compl1_it_hd, 0, 'C');
            }

            // Texte complémentaire N°2
            if ($txt_ent_compl2_it_hd <> '') {
                $this->SetY($pv_ent_hd + 14);
                $this->Cell(95 + $this->add_margin);
                $this->SetFont('', 'I', 7);
                $this->MultiCell(95, 5, $txt_ent_compl2_it_hd, 0, 'C');
            }

            // Code-Barre

            // Style du code-barre
            $style = [
                'position' => '',
                'align' => 'C',
            ];

            if (($txt_cb<> '') AND ctype_alnum ($txt_cb)) {
                $this->write1DBarcode($txt_cb, 'C39', 125 + $this->add_margin, 24, 55, 4, 0.4, $style, 'N');
            }

            // On récupère les coordonnées 'Y' les plus basses
            $pv_maxi_ent = max($pv_ent_hg, $pv_ent_hd);

            // Texte complémentaire
            if ($txt_ent_compl_hd <> '') {
                $this->SetY($pv_maxi_ent - 6);
                $this->Cell(95 + $this->add_margin);
                $this->SetTextColor(200);
                $this->SetFont('', 'B', 14);
                $this->Cell(95, 5, $txt_ent_compl_hd, 0, 1, 'C');
                $this->SetTextColor(0);
            }

            // Texte complémentaire
            if ($txt_type_etat <> '') {
                $this->SetY($pv_maxi_ent - 5);
                $this->Cell(95 + $this->add_margin);
                $this->SetFont('', 'I', 8);
                $this->Cell(95, 5, $txt_type_etat, 0, 1, 'R');
            }

            // Ligne de séparation
            if (($this->theader <> 'coupc') AND ($this->theader <> 'coupma')) {
                $this->SetDrawColor(125);
                $this->SetLineWidth(0.4);
                $this->Line(10, $pv_maxi_ent, 200 + $this->add_margin, $pv_maxi_ent);
                $this->SetDrawColor(0);
                $this->SetLineWidth(0.2);
            }

            $pv_maxi_ent++;

            $this->SetTopMargin($pv_maxi_ent); // Renvoie le pointeur SOUS l'entête agence

            // On restaure la couleur
            $this->SetTextColor($ex_couleurtxt);

            // On restaure la marge

            // $this->SetLeftMargin($ex_lMargin);
        }
    }

    /**
     * Pied de page
     */
    public function Footer()
    {
        // On sauve la couleur en cours en on se met en noir
        $ex_couleurtxt = $this->TextColor;
        $this->SetTextColor(0);

        //Positionnement à 1,5 cm du bas
        $this->SetY(-15);
        //Police Arial italique 8
        $this->SetFont('', 'I', 8);
        //Numéro de page
        $this->Cell(0, 10, 'Page ' . $this->getAliasNumPage() . '/' . $this->getAliasNbPages(), 0, 0, 'R');

        // On restaure la couleur
        $this->SetTextColor($ex_couleurtxt);
    }
}
